"""Pipelnes dict."""
# pylint: disable=line-too-long,too-many-lines

PIPELINE_BY_IDS = {
  '250001027905': 'Газосборный коллектор куста газоконденсатных скважин № 2А02 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '1154041': '(Комсомольский) Ики-Бурул-Элиста',
  '250000701301': 'Kоллектор газовый -I нитка газопровода-отвода на Уренгойскую ГРЭС Уренгойское НГКМ',
  '1158308': 'c.Усолье, р.Кама, 8,2 км',
  '1256584': 'АГРС-1 (1 оч.) - АГРС-1 (2оч.)',
  '1253050': 'Аборино-Щитниково 1',
  '1253052': 'Аборино-Щитниково 2',
  '1582067': 'Азнакаево-2',
  '160002354381': 'Акрон (новый)',
  '1153948': 'Александровская-Ленинградская',
  '1253212': 'Алексеевский цем.з-д, 2 н.',
  '20000513831': 'Анапа-Тамань',
  '1154110': 'Анастасиевская-Темрюк II',
  '1258960': 'Аргаяшская ТЭЦ',
  '1154055': 'Астраханский ГПЗ-Замьяны',
  '1154025': 'Астраханский ГПЗ-Камыш-Бурун',
  '1252934': 'Аэропорт "Домодедово", 1 н.',
  '220000533430': 'БТК Киринского ГКМ - ГКС Сахалин',
  '1153838': 'Багаевка-П.Умет-Кологривовка',
  '1153917': 'Багаевка-Сторожевка',
  '160001738126': 'Багратионовск',
  '1581410': 'Барнаул-Бийск',
  '1254762': 'Бежецк',
  '1153950': 'Бейсуг-Привольная',
  '1159061': 'Бейсуг-Привольная, р/н канал  БНВХ, 38,6 км',
  '1843462': 'Бейсуг-Привольная, р/н пруд, 42,6 км',
  '1153761': 'Белоусово-Ленинград',
  '1154051': 'Березанская КС-Славянск-на-Кубани',
  '1159082': 'Березанская КС-Славянск-на-Кубани, р/н р. Лев. Бейсужек, 47,642 км',
  '1159085': 'Березанская КС-Славянск-на-Кубани, р/н р. Протока, 154,344 км',
  '220000080899': 'Бийск-Горно-Алтайск',
  '210000348288': 'Бованенково-Ухта I',
  '210000865459': 'Бованенково-Ухта I, р/н., Байдарацкая Губа, 124,96-192,28км',
  '210000866572': 'Бованенково-Ухта I, р/н., р.Б.Сыня, 795,5км',
  '210000865468': 'Бованенково-Ухта I, р/н., р.Воркута, 441км',
  '210000894996': 'Бованенково-Ухта I, р/н., р.Ижма, 1105 км',
  '210000865465': 'Бованенково-Ухта I, р/н., р.Кара, 302,1км',
  '210000866579': 'Бованенково-Ухта I, р/н., р.Кожим, 711,2км',
  '210000866576': 'Бованенково-Ухта I, р/н., р.Косью, 736,3км',
  '210000865462': 'Бованенково-Ухта I, р/н., р.Нярма-Яха, 247км',
  '210000866568': 'Бованенково-Ухта I, р/н., р.Печора, 855,2км',
  '210000866582': 'Бованенково-Ухта I, р/н., р.Уса, 566,6км',
  '210000865581': 'Бованенково-Ухта I, р/н., р.Чикшина, 906,6км',
  '210001272223': 'Бованенково-Ухта II',
  '210001272897': 'Бованенково-Ухта II, р/н., Байдарацкая Губа, 122,97',
  '1254344': 'Бологое',
  '1253188': 'Боровичи 1 нитка',
  '1253190': 'Боровичи 2 нитка',
  '220000081339': 'Братское ГКМ - 45 мкр. г.Братска',
  '1153817': 'Брянск-Смоленск',
  '1153675': 'Бухара-Урал I',
  '1153676': 'Бухара-Урал II',
  '1153677': 'Бухара-Урал III',
  '7144587': 'Бухарский газоносный район Ташкент - Бишкек - Алматы  II очередь',
  '7110471': 'Бухарский газоносный район Ташкент - Бишкек - Алматы I очередь ',
  '400000216942': 'Бухарский газоносный район Ташкент-Бишкек-Алматы I очередь (реконструкция)',
  '400000214846': 'Бухарский газоносный район Ташкент-Бишкек-Алматы II очередь (строительство)',
  '1257100': 'Быково-Волжский',
  '1153762': 'Валдай-Псков-Рига',
  '1252680': 'Великие Луки',
  '1153981': 'Вильнюс-Калининград',
  '160000319410': 'Вильнюс-Калининград-2',
  '1153808': 'Владимир-КГМО',
  '180000244785': 'Внутрипромысловый конденсатопровод УКПГ-2В - ПХЗК Ду325',
  '1251896': 'Вологда-Череповец',
  '1158581': 'Вологда-Череповец, р/н., р. Шексна, 131,3 км',
  '160002354354': 'Волосовская',
  '1258556': 'Волхов - Петрозаводск',
  '1255536': 'Волхов-1',
  '1255526': 'Волхов-2',
  '1253916': 'Восточная',
  '1153847': 'Вуктыл-Зап.Соплеск',
  '1159008': 'Вуктыл-Ухта I, р/н., р. Печора, 35,5 км',
  '1153800': 'Вуктыл-Ухта II',
  '1158578': 'Вуктыл-Ухта II, р/н., р. Ижма, 191,07 км',
  '1158579': 'Вуктыл-Ухта II, р/н., р. Печора, 35,5 км',
  '1255082': 'Выборг',
  '1581473': 'Выборгская целлюлоза',
  '1253922': 'Вязьма',
  '1254664': 'Г-О к гг. Орск-Новотроицк 1н.',
  '1256904': 'Г-О к гг. Орск-Новотроицк 2н.',
  '1158088': 'Г-д внешнего т-та Восточно-Таркосалинского ГП',
  '2159830': 'Г-д внешнего тр-та Вынгаяхинского м-ия',
  '1153807': 'Г-д внешнего тр-та Комсомольского м-ия',
  '1154065': 'Г-д закольцевание Буйнакского и Ленинского р-нов',
  '3679977': 'Г-д неочищенного газа Копанского НГКМ (УСНГ-УКПГ-10)',
  '1581710': 'Г-д неочищенного газа УКПГ-9 2н.-УКПГ-8 1,2 н.н.',
  '1158065': 'Г-д неочищенного газа УКПГ10-ОГПЗ',
  '1158060': 'Г-д неочищенного газа УКПГ12-УКПГ2',
  '1581680': 'Г-д неочищенного газа УКПГ14-ОГПЗ',
  '260000778124': 'Г-д неочищенного газа УКПГ15-ОГПЗ (участок 0-15,71 км)',
  '1158068': 'Г-д неочищенного газа УКПГ16 1н.-ОГПЗ',
  '1158069': 'Г-д неочищенного газа УКПГ16 2н.-ОГПЗ',
  '1158054': 'Г-д неочищенного газа УКПГ2 1н.-ОГПЗ',
  '2159390': 'Г-д неочищенного газа УКПГ2 1н.-ОГПЗ (газы регенерации)',
  '1158055': 'Г-д неочищенного газа УКПГ2 2н.-ОГПЗ',
  '1158056': 'Г-д неочищенного газа УКПГ3 1н.-ОГПЗ',
  '1158057': 'Г-д неочищенного газа УКПГ3 2н.-ОГПЗ',
  '1158059': 'Г-д неочищенного газа УКПГ6 2н.-ОГПЗ',
  '1158062': 'Г-д неочищенного газа УКПГ8 1н.-ОГПЗ',
  '1158063': 'Г-д неочищенного газа УКПГ8 2н.-ОГПЗ',
  '1158064': 'Г-д неочищенного газа УКПГ9 1н.-ОГПЗ',
  '1581707': 'Г-д подкл. ЯГКМ к Уренгой Надым I',
  '1154060': 'Г-д подключение Вынгапуровского м-ия',
  '3146806': 'Г-д подключения Губкинского ГП',
  '30004303422': 'Г/п отвод к ГРС Юрьевец Ивановской области',
  '1259056': 'ГГ. Шатрово Талица',
  '1158364': 'ГО Боровичи 1 нитка, РН, р. Мста, 61.1 км',
  '1158365': 'ГО Боровичи 2 нитка, РН, р. Мста, 58 км',
  '210001272664': 'ГП-1',
  '210000864030': 'ГП-2/1',
  '210000864033': 'ГП-2/2',
  '210001595356': 'ГП-3',
  '6492097': 'ГП-перемычка Моздок-Кази-Магомед - Аксай-Гудермес-Грозный',
  '1257050': 'ГРС Акъяр',
  '1257012': 'ГРС Баймак',
  '1255268': 'ГРС Белорецк 1н',
  '1255266': 'ГРС Белорецк 2н',
  '1257982': 'ГРС Большеустикинское',
  '210000005865': 'ГРС Большое село',
  '1581461': 'ГРС Борисоглебский',
  '1255320': 'ГРС Борок',
  '1259384': 'ГРС Великий Устюг',
  '210000101285': 'ГРС Верховажье',
  '1254748': 'ГРС Вологда',
  '210003202518': 'ГРС Воркута-1',
  '210004062280': 'ГРС Воркута-2',
  '1255056': 'ГРС Гаврилов-Ям',
  '1257970': 'ГРС Гайва (1 оч.)',
  '90000652831': 'ГРС Глушково в с.Веселое',
  '1255170': 'ГРС Давлеканово',
  '1253554': 'ГРС Кадуй',
  '210000214774': 'ГРС Кадуй, р/н., р.Суда, 9км',
  '210000001268': 'ГРС Калязин',
  '1257792': 'ГРС Карманово',
  '1158163': 'ГРС Карманово,р/н.,р.Бирь,16.7км',
  '1254064': 'ГРС Коряжма',
  '1253372': 'ГРС Котлас',
  '1253906': 'ГРС Крутянская',
  '1159036': 'ГРС Крутянская, р/н, р. Ижма, 7.3 км',
  '1255156': 'ГРС Куратово',
  '1254002': 'ГРС Любимская',
  '1251554': 'ГРС Нажировка',
  '210004921357': 'ГРС Нея',
  '210000546959': 'ГРС Новодвинск',
  '6943021': 'ГРС Парфеньево',
  '1254512': 'ГРС Петровск',
  '210001803597': 'ГРС Печора-2 (Ду 300)',
  '210000055265': 'ГРС Плесецк',
  '990008604816': 'ГРС Пудож',
  '210000546969': 'ГРС Северодвинск',
  '210000547216': 'ГРС Северодвинск, р/н р. Лая, 52 км',
  '1255624': 'ГРС Сибай',
  '1253902': 'ГРС Сокол',
  '1256638': 'ГРС Тазларово',
  '1253854': 'ГРС Углич',
  '1257058': 'ГРС Учалы',
  '1258964': 'ГРС Чагода',
  '1256468': 'ГРС Чебаково',
  '1581773': 'ГРС Шарья',
  '1254906': 'ГРС Ярега',
  '1256532': 'ГРС г.Новоалтайска',
  '90000358943': 'ГРС с. Кашары',
  '1581755': 'ГРС-1 Вельск',
  '1258482': 'ГРС-1 Рыбинск',
  '1251898': 'ГРС-1 Череповец',
  '1252972': 'ГРС-1 г.Рязань',
  '1254836': 'ГРС-1 г.Сыктывкар',
  '1158590': 'ГРС-1 г.Сыктывкар, р/н., р. Вымь, 23,7 км',
  '1158591': 'ГРС-1 г.Сыктывкар, р/н., р. Вычегда, 50,7 км',
  '190000309991': 'ГРС-1 н.п. Елизаветино',
  '210000418924': 'ГРС-2 Архангельск(Уйма)',
  '220000142970': 'ГРС-2 г.Бийск',
  '1253914': 'ГРС-3 Рыбинск',
  '1255204': 'ГРС-4 Череповец',
  '250000797399': 'ГСК кустов 1019, 1022, 1026 УНГКМ от КУ №3 до ППА УКПГ-10',
  '80000008964': 'Газ продувки 4УП-ГПЗ',
  '80000008979': 'Газ продувки 9УП-ГПЗ',
  '80000008967': 'Газ продувки УППГ4-4УП',
  '80000009905': 'Газ продувки УППГ9-9УП',
  '20000112846': 'Газовый колектор от ГУ1 до ГУ5 Староминского месторождения',
  '80000295164': 'Газоконденсатопровод УППГ-4 до АГПЗ',
  '80000295156': 'Газоконденсатопровод УППГ-6-ГПЗ I т.н.',
  '80000010545': 'Газоконденсатопровод УППГ1-ГПЗ 4нитка',
  '80000008961': 'Газоконденсатопровод УППГ2-ГПЗ 1нитка',
  '80000185029': 'Газоконденсатопровод УППГ6-ГПЗ 2 нитка ',
  '180000000313': 'Газопровод -коллектор подключения УКПГ 1В 1нитка Ду 1000  ',
  '220000756097': 'Газопровод БТК Киринского ГКМ-ГКС Сахалин, р/н р.Тымь',
  '1153799': 'Газопровод Вуктыл-Ухта 1',
  '20000448360': 'Газопровод Кореновск-Выселки (новый)',
  '20000456551': 'Газопровод Кореновск-Динская (новый)',
  '50001909084': 'Газопровод высокого давления от УКПГ-22 до АГРС',
  '1158053': 'Газопровод неочищенного газа УКПГ1-ДКС2',
  '400000227812': 'Газопровод отвод ГРС-2 (Реконструкция)',
  '1252142': 'Газопровод отвод к ГРС Б.Калитва (Сельмаш)',
  '1251538': 'Газопровод отвод к ГРС Б.Калитва БКМЗ',
  '1259152': 'Газопровод отвод к г. Каменск-Шахтинский',
  '230001678499': 'Газопровод подключения №1 Волгоградского ПХГ к МГ Починки - Изобильное',
  '230001678504': 'Газопровод подключения №2 Волгоградского ПХГ к МГ Починки - Изобильное',
  '230001678645': 'Газопровод подключения Волгоградского ПХГ к г-о к г.Волгограду 1 очередь',
  '150000605894': 'Газопровод подключения УКПГ Берегового НГКМ',
  '290001278635': 'Газопровод подключения УППГ-4',
  '150000063067': 'Газопровод товарного газа Южно-Русское НГМ - КС Пуртазовская',
  '180000000538': 'Газопровод-коллектор подключение УКПГ 9 к МГ Ду 1200 ',
  '180000000317': 'Газопровод-коллектор подключения УКПГ 1В     2 нитка Ду 1000',
  '20000331364': 'Газопровод-лупинг  Ленинградская - Ейск (участок ГУ-1- ст. Старощербиновская)',
  '40001525374': 'Газопровод-отвод «Макат-Северный Кавказ - Хошеутово - Вольное - Харабали',
  '400000241267': 'Газопровод-отвод Бишкек-Кант-Токмок',
  '1253422': 'Газопровод-отвод ГРС №2 Липецк',
  '2249762': 'Газопровод-отвод ГРС №5, Липецк, НЛМК.',
  '100001234125': 'Газопровод-отвод ГРС Введенское',
  '1254740': 'Газопровод-отвод ГРС Задонск',
  '7144610': 'Газопровод-отвод ГРС-1 Пригородное',
  '220000469869': 'Газопровод-отвод ГРС-3 г.Хабаровск',
  '220000080915': 'Газопровод-отвод ГРС-Белокуриха',
  '1153892': 'Газопровод-отвод Западный Соплеск(узел комплексной подготовки газа)-ГРС-2(Печора)',
  '1258262': 'Газопровод-отвод Новоспасск-Ульяновск',
  '60000373530': 'Газопровод-отвод Сызрань-Ульяновск',
  '100001234131': 'Газопровод-отвод Юргамыш-Курган',
  '220000498274': 'Газопровод-отвод и ГРС с. Нижняя Каянча',
  '90002652197': 'Газопровод-отвод к АГРС Воротынск',
  '90001679795': 'Газопровод-отвод к АГРС Конышевка',
  '7466772': 'Газопровод-отвод к ГРС "Гуково"',
  '7144603': 'Газопровод-отвод к ГРС - Кара-Тау с 1-очереди',
  '20000448340': 'Газопровод-отвод к ГРС №4а г.Краснодара',
  '7144606': 'Газопровод-отвод к ГРС Беловодское',
  '7144601': 'Газопровод-отвод к ГРС Военсовхоз',
  '150003234657': 'Газопровод-отвод к ГРС Ишим',
  '220003511389': 'Газопровод-отвод к ГРС ЛПУМГ в г. Алдан',
  '7144609': 'Газопровод-отвод к ГРС Маловодное',
  '220001400247': 'Газопровод-отвод к ГРС Ноглики',
  '220001494214': 'Газопровод-отвод к ГРС Ордынское',
  '220001400233': 'Газопровод-отвод к ГРС Ребриха',
  '400000216338': 'Газопровод-отвод к ГРС Сокулук (Реконструкция)',
  '220000398088': 'Газопровод-отвод к ГРС-1 г.Владивосток',
  '1257746': 'Газопровод-отвод к ГРС-10 с.Васильевка (Ду500)',
  '1258118': 'Газопровод-отвод к ГРС-110 р.ц.Исаклы',
  '1159042': 'Газопровод-отвод к ГРС-110 р.ц.Исаклы, р/н, р.Сок',
  '1257742': 'Газопровод-отвод к ГРС-116 р.ц.Борское',
  '1159047': 'Газопровод-отвод к ГРС-116 р.ц.Борское, р/н, р. Самара, 33,07 км',
  '1255984': 'Газопровод-отвод к ГРС-117 р.ц.Кошки',
  '1257758': 'Газопровод-отвод к ГРС-12 с.Елховка',
  '1255968': 'Газопровод-отвод к ГРС-127 р.ц.Большая Черниговка',
  '1258074': 'Газопровод-отвод к ГРС-132 р.ц.Сурское',
  '1258348': 'Газопровод-отвод к ГРС-134 ст.Бичевная',
  '1255988': 'Газопровод-отвод к ГРС-16 пгт Алексеевка',
  '1255996': 'Газопровод-отвод к ГРС-17 г.Новокуйбышевск',
  '60000016977': 'Газопровод-отвод к ГРС-17 г.Новокуйбышевск (лупинг)',
  '1255992': 'Газопровод-отвод к ГРС-18 с.Рубежное',
  '1258190': 'Газопровод-отвод к ГРС-19А с.Русская Борковка (Ду700)',
  '1258082': 'Газопровод-отвод к ГРС-2 п.Петра-Дубрава',
  '1258076': 'Газопровод-отвод к ГРС-23 п.Октябрьский',
  '1257702': 'Газопровод-отвод к ГРС-25 г.Чапаевск',
  '1257750': 'Газопровод-отвод к ГРС-30 п.Винтай',
  '1258350': 'Газопровод-отвод к ГРС-32 п.Ровный',
  '1258116': 'Газопровод-отвод к ГРС-33 р.ц.Шентала',
  '1255974': 'Газопровод-отвод к ГРС-38 г.Ульяновск',
  '60000045012': 'Газопровод-отвод к ГРС-38 г.Ульяновск (лупинг)',
  '1257722': 'Газопровод-отвод к ГРС-39 с.Приволжье',
  '1255040': 'Газопровод-отвод к ГРС-4 г.Новосибирск',
  '1256004': 'Газопровод-отвод к ГРС-43 г.Ульяновск',
  '1258092': 'Газопровод-отвод к ГРС-47 р.ц.Русский Камешкир',
  '7910283': 'Газопровод-отвод к ГРС-52 Крестово Городище',
  '1254274': 'Газопровод-отвод к ГРС-62 р.ц.Пестравка',
  '60000760326': 'Газопровод-отвод к ГРС-8 г. Бугуруслан',
  '1258078': 'Газопровод-отвод к ГРС-85 с.Игнатовка',
  '1256788': 'Газопровод-отвод к ГРС-86 р.ц.Хворостянка',
  '1258098': 'Газопровод-отвод к ГРС-90 с.Новый Ризадей',
  '1258264': 'Газопровод-отвод к ГРС-91 г.Жигулевск',
  '1258326': 'Газопровод-отвод к ГРС-92 г.Сызрань',
  '1258096': 'Газопровод-отвод к ГРС-96 г.Кузнецк',
  '1258088': 'Газопровод-отвод к ГРС-98 с.Анненково',
  '1256790': 'Газопровод-отвод к ГРС-99 р.ц.Большая Глушица',
  '220000226957': 'Газопровод-отвод к ГРС-Алтайское',
  '7144604': 'Газопровод-отвод к ГРС-Каинда',
  '170001014637': 'Газопровод-отвод к ПГУ от узла измерения газа до охранного крана. Трасса 1',
  '170001014651': 'Газопровод-отвод к ПГУ от узла измерения газа до охранного крана. Трасса 2',
  '1258144': 'Газопровод-отвод к ПЗРГ ГРС-16 пгт Алексеевка',
  '1258250': 'Газопровод-отвод к ПЗРГ с.Новый Буян',
  '60001384354': 'Газопровод-отвод к УЗРГ (подключение к МГ "Уренгой-Петровск")',
  '1252184': 'Газопровод-отвод к г.Хвалынск',
  '220000081293': 'Газопровод-отвод к пос.Эльбан',
  '8675916': 'Газопровод-отвод магистральный ГРС Верхнее Джемете',
  '310002381186': 'Газопровод-отвод магистральный морской терминала по приему, хранению и регазификации СПГ Калининградской области',
  '310001138616': 'Газопровод-отвод магистральный сухопутный терминала по приему, хранению и регазификации СПГ Калининградской области',
  '250000701310': 'Газопровод-отвод на ГРЭС ст. Тихая 2-я нитка Уренгойское НГКМ',
  '20000512373': 'Газопровод-отвод от газопровода Джубга-Лазаревское-Сочи до Туапсинского НПЗ',
  '220000081252': 'Газопровод-отвод пос.Хурба',
  '260000619541': 'Газопровод-перемычка ДКС-1 - ДКС-2',
  '20000630611': 'Газопровод-перемычка КС Кубанская - КС Кореновская Южно-Европейского газопровода',
  '1255166': 'Газопровод-перемычка Оренбург-Совхозное ПХГ',
  '1153922': 'Газопровод-перемычка к МГ Отрадненский ГПЗ-КАТЗ',
  '90004671254': 'Газопровод-перемычка между Перемычка между Уренгой-Центр I и КС-7А (6,3км) и МГ Елец-Новопсков-ССПХГ (0км)',
  '250000781283': 'Газопровод-подключение к УКПГ-11 2 нитка ',
  '250000781836': 'Газопровод-подключение к УКПГ-12 1 нитка ',
  '250000781883': 'Газопровод-подключение к УКПГ-12 2 нитка ',
  '250000790073': 'Газопровод-подключение к УКПГ-4 1 нитка ',
  '250000790077': 'Газопровод-подключение к УКПГ-4 2 нитка ',
  '250000772777': 'Газопровод-подключение к УКПГ-5 1 нитка ',
  '250000772767': 'Газопровод-подключение к УКПГ-5 2 нитка ',
  '250000769157': 'Газопровод-подключение к УКПГ-6 1 нитка',
  '250000768101': 'Газопровод-подключение к УКПГ-7 1 нитка ',
  '250000768118': 'Газопровод-подключение к УКПГ-7 2 нитка ',
  '80000909570': 'Газопровод-шлейф скважины № 612',
  '80000788463': 'Газопровод-шлейф скважины газовой эксплуатационной № 631 УППГ-6 Астраханского ГКМ',
  '250001799139': 'Газосборный коллектор ЗПП от КУ №1 до УКПГ-16',
  '250001363769': 'Газосборный коллектор куста №2А25 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001364208': 'Газосборный коллектор куста №2А29 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ_x000D_',
  '250001364403': 'Газосборный коллектор куста №2А34 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ_x000D_',
  '250001027898': 'Газосборный коллектор куста газоконденсатных скважин № 2А01 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001257475': 'Газосборный коллектор куста газоконденсатных скважин № 2А03 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ ',
  '250001027901': 'Газосборный коллектор куста газоконденсатных скважин № 2А05 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001257520': 'Газосборный коллектор куста газоконденсатных скважин № 2А20 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001258444': 'Газосборный коллектор куста газоконденсатных скважин № 2А24 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001258447': 'Газосборный коллектор куста газоконденсатных скважин № 2А26 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001258450': 'Газосборный коллектор куста газоконденсатных скважин № 2А27 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001258453': 'Газосборный коллектор куста газоконденсатных скважин № 2А28 УКПГ-21 второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250000173409': 'Газосборный коллектор куста газоконденсатных скважин №208 ГКП-22',
  '250000173360': 'Газосборный коллектор куста газоконденсатных скважин №209 ГКП-22',
  '250000137386': 'Газосборный коллектор куста газоконденсатных скважин №211 ГКП-22',
  '250000137389': 'Газосборный коллектор куста газоконденсатных скважин №212 ГКП-22',
  '250000173100': 'Газосборный коллектор куста газоконденсатных скважин №213 ГКП-22',
  '250000722304': 'Газосборный коллектор куста газоконденсатных скважин №2А06 ГКП-22',
  '250000722317': 'Газосборный коллектор куста газоконденсатных скважин №2А07 ГКП-22',
  '250000660845': 'Газосборный коллектор куста газоконденсатных скважин №2А14 ГКП-22',
  '250000660869': 'Газосборный коллектор куста газоконденсатных скважин №2А15 ГКП-22',
  '250000943836': 'Газосборный коллектор куста газоконденсатных скважин №2А16 ГКП-22',
  '250000943842': 'Газосборный коллектор куста газоконденсатных скважин №2А17 ГКП-22',
  '250000722324': 'Газосборный коллектор куста газоконденсатных скважин №2А18 ГКП-22',
  '250000943848': 'Газосборный коллектор куста газоконденсатных скважин №2А23 ГКП-22',
  '250000504592': 'Газосборный коллектор куста газоконденсатных скважин №2А31 ГКП-22',
  '250000504645': 'Газосборный коллектор куста газоконденсатных скважин №2А32 ГКП-22',
  '250000660875': 'Газосборный коллектор куста газоконденсатных скважин №2А35 ГКП-22',
  '250000943855': 'Газосборный коллектор куста газоконденсатных скважин №2А36 ГКП-22',
  '250000943861': 'Газосборный коллектор куста газоконденсатных скважин №2А37 ГКП-22',
  '250000943868': 'Газосборный коллектор куста газоконденсатных скважин №2А38 ГКП-22',
  '250000504678': 'Газосборный коллектор куста газоконденсатных скважин №2А39 ГКП-22',
  '210000765339': 'Галич-Мантурово-Шарья',
  '1153941': 'Гиагинская-Динская',
  '1153947': 'Гиагинская-Новокубанская',
  '1254686': 'Гнездово',
  '1158052': 'Голубой поток - Россия-Турция (морской вариант)',
  '2402397': 'Голубой поток I',
  '2402401': 'Голубой поток II',
  '1153672': 'Горький-Центр',
  '1158756': 'Горький-Центр, р/н р. Ока, 155,4 км',
  '1153890': 'Горький-Центр-КС Серпухов',
  '1153809': 'Горький-Череповец',
  '1158582': 'Горький-Череповец, р/н., р. Волга-1, 403 км',
  '1158217': 'Горький-Череповец, р/н., р. Которосль, 330,4 км',
  '1158583': 'Горький-Череповец, р/н., р. Согожа, 468.7 км',
  '210000000350': 'Горький-Череповец, р/н., р. Ухра, 449.4 км',
  '1153776': 'Грязовец-КГМО',
  '1158216': 'Грязовец-КГМО, р/н., р. Волга, 134,42 км',
  '1153755': 'Грязовец-Ленинград I',
  '1153780': 'Грязовец-Ленинград II',
  '1158587': 'Грязовец-Ленинград II, р/н., р. Шексна, 131,36 км',
  '1153784': 'Грязовец-Торжок',
  '1154139': 'Грязовец-Торжок (лупинг)',
  '1582052': 'Грязовец-Торжок IV',
  '1154134': 'Грязовец-Торжок IV (лупинг)',
  '1158627': 'Грязовец-Торжок IV, р/н., р. Волга-1, 1058,46 км',
  '1158628': 'Грязовец-Торжок IV, р/н., р. Волга-2, 1098,7 км',
  '160000516292': 'Гусев',
  '1255124': 'Гусинский завод',
  '1153856': 'ДКБМ-Калуга-Белоусово',
  '40000077200': 'ДКС-2 - КС-1',
  '1153709': 'Дашава-Киев-Брянск-Москва',
  '2249695': 'Дашава-Киев-Брянск-Москва (лупинг)',
  '1254436': 'Дедовичи',
  '20000277394': 'Джубга-Лазаревское-Сочи',
  '40000218056': 'Дзуарикау-Цхинвал',
  '1153835': 'Дмитриевский СП-Жирновск-Кологривовка',
  '1153833': 'Дмитриевский СП-Зап.Рыбушка',
  '1153789': 'Долгодеревенская-Красногорск (Б-Урал II)',
  '1153788': 'Долгодеревенская-Сысерть (Б-Урал II)',
  '1153766': 'Домбаровка-Оренбург',
  '240005340990': 'Дублирующая врезка газопровода подключения Песцового месторождения',
  '230000150321': 'Елань Колено',
  '1153770': 'Елец-Кременчуг-Кривой Рог',
  '1153707': 'Елец-Курск-Диканька',
  '1153706': 'Елец-Курск-Киев',
  '1158182': 'Елец-Курск-Киев, р/н., р. Сосна, 25 км',
  '1153891': 'Елец-Новопсков-Североставропольская СПХГ',
  '1158222': 'Елец-Новопсков-Североставропольская СПХГ, р/н., р. Сосна, 6 км',
  '1153778': 'Елец-Серпухов',
  '1158034': 'Елец-Щекино',
  '1253380': 'Ельня',
  '1153930': 'Ермолинское-Астрахань',
  '1153768': 'Жирновск-Кологривовка',
  '1159110': 'Заполярное-Уренгой I',
  '1159684': 'Заполярное-Уренгой II',
  '1581779': 'Заполярное-Уренгой III',
  '150000364726': 'Заполярное-Уренгой III лупинг',
  '150000348820': 'Заполярное-Уренгой III,р/н.,р.Пур, 115 км',
  '70000103088': 'Знаменка-Токаревка',
  '1154048': 'Игрим-Пунга',
  '1153773': 'Игрим-Серов-Н.Тагил',
  '1157759': 'Игрим-Серов-Н.Тагил, р/н., р. Лобва, км 532,7',
  '1157826': 'Игрим-Серов-Н.Тагил, р/н., р. Лозьва, км 361,8',
  '1157830': 'Игрим-Серов-Н.Тагил, р/н., р. Сосьва, км 413,15',
  '1157762': 'Игрим-Серов-Н.Тагил, р/н., р. Эсс, км 194,5',
  '1157758': 'Игрим-Серов-Н.Тагил, р/н., р.Ивдель, 369,5 км',
  '1157760': 'Игрим-Серов-Н.Тагил, р/н., р.Пелым, км 274,25',
  '1154135': 'Игрим-Серов-Нижний Тагил (лупинг)',
  '1154037': 'Изборск-Инчукалнское ПХГ',
  '1154021': 'Изборск-Тарту',
  '1153824': 'Изобильное-Невинномысск',
  '1253398': 'Изоплит',
  '1255022': 'Ильичево',
  '1258566': 'Ириклинская ГРЭС',
  '1153793': 'Ишимбай-Уфа',
  '1153961': 'Ищерская-Моздок',
  '1154032': 'КГМО I',
  '90001750507': 'КГМО I, уч-к КС Воскресенск-КС Серпухов (реконструкция)',
  '1581791': 'КГМО I, уч-к КС Ногинск-КС Воскресенск (реконструкция)',
  '1154031': 'КГМО II',
  '1153852': 'КГМО-Белоусово',
  '1251892': 'КРП-10, 2н.',
  '1251478': 'КРП-11',
  '1253666': 'КРП-13, Химки-Крюково (I н.)',
  '1253704': 'КРП-13, Химки-Крюково (II н.)',
  '1154033': 'КРП-14 - Серпухов (КГМО-II)',
  '1253792': 'КРП-14, 1 н.',
  '1253830': 'КРП-14, 2 н.',
  '1158294': 'КРП-14, 2 н., р/н., р. Москва, 14,7 км',
  '1252732': 'КРП-16',
  '1252942': 'КРП-17, д.Бородино',
  '1253944': 'КС Вятская-Киров',
  '1153958': 'КС Журавская-Канглы',
  '1154000': 'КС Изобильное-КС Рождественская',
  '40000664417': 'КС Изобильный - Невинномысск',
  '1153857': 'КС Путятино-Увязовское ПХГ',
  '8474647': 'КС Путятино-Увязовское ПХГ (лупинг)',
  '1581677': 'КС Сохрановка-КС Октябрьская',
  '1158035': 'КС Щекинская - КС Щекино',
  '160002354388': 'КСПГ Высоцк',
  '1154023': 'Казань-Горький',
  '1153909': 'Казань-Йошкар-Ола',
  '1153714': 'Кази-Магомед-Моздок',
  '1251904': 'Калинин-1',
  '1253924': 'Калинин-2',
  '40000083252': 'Каменная Балка - Журавское',
  '1153960': 'Камыш-Бурун-Горагорский',
  '1154046': 'Камыш-Бурун-Ищерская',
  '1153943': 'Каневская - Усть-Лабинск',
  '1258588': 'Карашурское УПХГ',
  '1153791': 'Карталы-Магнитогорск I',
  '1153792': 'Карталы-Магнитогорск II',
  '1154030': 'Касимовская СПХГ-КГМО',
  '90000154657': 'Касимовское ПХГ-КС Воскресенск',
  '1153968': 'Каспийск-Ачи-Су',
  '1254912': 'Кашин',
  '40000083255': 'Кевсала - Ульяновка',
  '1256898': 'Киембаевский ГОК',
  '1258552': 'Кингисепп - Сланцы',
  '160001330230': 'Кириши',
  '1252818': 'Кировск',
  '1581488': 'Кирсанов-Тамбов',
  '1158982': 'Коллектор газовый -перемычка №3 1нУKПГ8-9.Уренгойское НГКМ',
  '1158983': 'Коллектор газовый -перемычка №3 2нУKПГ-8-9, литерВ, Уренго йское НГКМ',
  '250000005277': 'Коллектор газовый -подключение УКПГ-15,1-я нитка.Северо-Уренгойское НГКМ',
  '250000700938': 'Коллектор газовый 3-я нитка УКПГ8-13 Уренгойское НГКМ',
  '250000700902': 'Коллектор газовый 3н.вост.кор. УКПГ-6-УКПГ-9. Уренгойское НГКМ.',
  '250000700512': 'Коллектор газовый 4н.вост.кор. УКПГ-6-УКПГ-9 Уренгойское НГКМ.',
  '250000700893': 'Коллектор газовый III н.вост.кор.УКПГ-3-6 Уренгойское НГКМ',
  '250000700882': 'Коллектор газовый III-я нитка вост.кор. УКПГ-3-ГКС Уренгойское НГКМ',
  '250000700508': 'Коллектор газовый IY нитка вост.кор. УКПГ-3-УКПГ6 Уренгойское НГКМ',
  '250000700504': 'Коллектор газовый IYн.вост.кор. УКПГ-3-ГКС2 Уренгойское НГКМ',
  '250000701079': 'Коллектор газовый УКП 13-15, 2н.,с подкл. УКПГ15,Северо-Уренгойское НГКМ',
  '250000700914': 'Коллектор газовый УКПГ 10-11, 1-я нитка. Уренгойское НГКМ',
  '250000701057': 'Коллектор газовый УКПГ 10-11, 2н.с подкл.УКПГ-11.Уренгойское НГКМ',
  '250000701041': 'Коллектор газовый УКПГ 11-12, 1-я нитка, с подкл.УКПГ12, Ен-Яхинская площадь Уренгойское НГКМ',
  '250000701068': 'Коллектор газовый УКПГ 11-12, 2н., с подкл. УКПГ12 Ен-Яхинская площадь Уренгойское НГКМ.',
  '250000700956': 'Коллектор газовый УКПГ 12-13, 1-я нитка. Ен-Яхинская площадь Уренгойское НГКМ',
  '250000700965': 'Коллектор газовый УКПГ 12-13, 2-я нитка. Ен-Яхинская площадь Уренгойское НГКМ',
  '250000700977': 'Коллектор газовый УКПГ 13-15 , 1н. Северо-Уренгойское НГКМ',
  '250000701220': 'Коллектор газовый УКПГ 9-10, 1-я нитка, литер В, Уренгойское НГКМ',
  '250000701234': 'Коллектор газовый УКПГ 9-10, 2н.с подключением УКПГ-9, литер В, Уренгойское НГКМ',
  '250000700926': 'Коллектор газовый УКПГ-2-ГКС1,2 Уренгойское НГКМ',
  '250000700935': 'Коллектор газовый УКПГ-3-ГКС1,2 Уренгойское НГКМ',
  '250000701130': 'Коллектор газовый УКПГ-4-5, 1-я нитка, с подключением УКПГ5 Уренгойское НГКМ',
  '250000701140': 'Коллектор газовый УКПГ-4-5, 2н.с подкл.УКПГ5 Уренгойское НГКМ.',
  '250000701376': 'Коллектор газовый УКПГ-4-ГКС 2, Iн.с подкл.УКПГ-4Уренгойское НГКМ',
  '250000701340': 'Коллектор газовый УКПГ-4-ГКС1,2 2н. с подкл.УКПГ4Уренгойское НГКМ.',
  '250000701150': 'Коллектор газовый УКПГ-5-6, 1-я нитка, с подключением УКПГ-6 Уренгойское НГКМ',
  '250000701170': 'Коллектор газовый УКПГ-5-6, II нитка, с подкл. УКПГ6. Уренгойское НГКМ.',
  '250000701180': 'Коллектор газовый УКПГ-6-7, 2н.с подкл.УКПГ7 Уренгойское НГКМ.',
  '250000701160': 'Коллектор газовый УКПГ-6-7. 1-я нитка, с подключением УКПГ 7 Уренгойское НГКМ',
  '250000701110': 'Коллектор газовый УКПГ-7-8 I нитка Уренгойское НГКМ',
  '250000701121': 'Коллектор газовый УКПГ-7-8 II нитка.Уренгойское НГКМ',
  '250000701194': 'Коллектор газовый УКПГ-8-9, Iн.с подкл.УКПГ9.Уренгойское НГКМ',
  '1158978': 'Коллектор газовый перемычка №1 1 нитка УKПГ 3-4 Уренгойское НГКМ',
  '1158979': 'Коллектор газовый- перемычка №1 2н.УKПГ 3-4 Уренгойское НГКМ',
  '1158981': 'Коллектор газовый-перемычка №2, II н.УKПГ-5 - 6 Уренгойское НГКМ',
  '1158970': 'Коллектор газовый-переход ч/з р. Ево-Яха III-2 н.восточного коридораУKПГ-3-ГКС 2 Уренгойское НГКМ',
  '1158972': 'Коллектор газовый-переход ч/з р. Ево-Яха IY-2н.УKПГ-3-ГКС-2 IYн.вост.коридора Уренгойское НГКМ',
  '250000005212': 'Коллектор газовый-подключение УКПГ8, 2-я нитка, литер В, Уренгойское НГКМ',
  '250000701209': 'Коллектор газовыйУКПГ 8-9, 2н.Уренгойское НГКМ',
  '1153899': 'Коломна-Рязань',
  '1154045': 'Комсомольский-Ики-Бурул (Элиста)',
  '1157874': 'Комсомольское-Челябинск',
  '1158506': 'Комсомольское-Челябинск, р/н.,  старица р. Исеть, 1381,1 км, р. Исеть, 1382,5 км',
  '1158702': 'Кон-д Оренбург-Салават-Уфа 3 н., р/н р. Белая, 396 км',
  '50000879337': 'Кон-д Уренгой - Сургут 2 р/н., р.Пурпе 188,8 км.',
  '50000879340': 'Кон-д Уренгой - Сургут 2 р/н., р.Пяку-Пур 223,5 км.',
  '50000879334': 'Кон-д Уренгой - Сургут 2 р/н., р.Тыдыотта 108,9 км, р.Салетьяха 117,3 км.  ',
  '1159108': 'Кон-д Уренгой-Сургут I, р/н., озеро, 676 км',
  '1158461': 'Кон-д Уренгой-Сургут I, р/н., р.Вынгапур, 293,9 км',
  '1159102': 'Кон-д Уренгой-Сургут I, р/н., р.Ева-Яха, 6,3 км',
  '1158464': 'Кон-д Уренгой-Сургут I, р/н., р.Ингу-Ягун, 570,28 км, р.Волоктоягун, 575,65 км, р.Тром-Еган, 589,7 км',
  '1158459': 'Кон-д Уренгой-Сургут I, р/н., р.Пурпе, 186,3 км',
  '1158460': 'Кон-д Уренгой-Сургут I, р/н., р.Пяку-Пур, 219,8 км',
  '1158457': 'Кон-д Уренгой-Сургут I, р/н., р.Тыдыотта, 111,7 км, р.Салетьяха, 113,4 км',
  '1159109': 'Кон-д Ямбург-Уренгой 1н., р/н., р. Хадуттэ, 60,6 км',
  '1251502': 'Конаково',
  '1157712': 'Конд-д Оренбург-Салават  2 н.',
  '1157710': 'Конд-д Оренбург-Салават-Уфа 3 н.',
  '1157711': 'Конд-д Оренбург-Салават-Уфа 4 н.',
  '260000778284': 'Конд-д УКПГ-15-ОГПЗ (участок 0-15,626 км)',
  '260000778294': 'Конд-д УКПГ-15-ОГПЗ (участок 15,807 - 50,49 км) ',
  '1158072': 'Конд-д УКПГ1-ДКС2',
  '1158073': 'Конд-д УКПГ10-ОГПЗ',
  '1158079': 'Конд-д УКПГ16 1н.-ОГПЗ',
  '1158080': 'Конд-д УКПГ16 2н.-ОГПЗ ',
  '1158081': 'Конд-д УКПГ16 3н.-ОГПЗ',
  '1158070': 'Конд-д УКПГ2-ОГПЗ',
  '2254507': 'Конд-д УКПГ3-УКПГ2',
  '1158071': 'Конд-д УКПГ6-ОГПЗ',
  '1158074': 'Конд-д УКПГ8-ОГПЗ',
  '1153813': 'Конд-д Уренгой-Сургут I',
  '1153814': 'Конд-д Уренгой-Сургут II',
  '1153815': 'Конд-д Ямбург-Уренгой I',
  '1157875': 'Конд-д Ямбург-Уренгой II',
  '2321937': 'Конд-д газа с регенерацией инвентарный номер 122158',
  '1159162': 'Конденсатопровод Вуктыл-СГПЗ 2-ая нитка    ',
  '50000097079': 'Конденсатопровод Заполярное НГКМ-г.Новый Уренгой',
  '50000122681': 'Конденсатопровод Заполярное НГКМ-г.Новый Уренгой р/н., р.Пур, 122,8 км',
  '2248268': 'Конденсатопровод УКПГ-11В-УПКТ(врезка в Ямбургскую  линию) Ен-Яхинского НГКМ',
  '250000136533': 'Конденсатопровод внешнего транспорта УКПГ-22, второго опытного участка Ачимовских отложений Уренгойского НГКМ',
  '250001290038': 'Конденсатопровод-перемычка от площадки узла запуска, приема очистных устройств 1 до кранового узла №6 конденсатопровода-перемычки между конденсатопроводом с участков 1А, 2А УНГКМ и УСК НПТР ',
  '2893827': 'Кондопога',
  '1254886': 'Конная Лахта',
  '1258554': 'Конная Лахта',
  '1156172': 'Конный-ГРС-4',
  '1153874': 'Коробки-Камышин I',
  '1153875': 'Коробки-Камышин II',
  '1153882': 'Коробки-Лог I',
  '1153883': 'Коробки-Лог II',
  '1153886': 'Коробки-Лог-Волгоград',
  '1154049': 'Коробки-Сторожевка',
  '160002314167': 'Кохтла-Ярве-Ленинград-2 (новый)',
  '1154001': 'Краснодар-Крымск',
  '1153743': 'Краснодарский край - Серпухов I',
  '1153744': 'Краснодарский край - Серпухов II',
  '1258586': 'Кромы-Орел (реконструкция)',
  '1255950': 'Крыловское ПГСП',
  '1153937': 'Крымск-Краснодар Уч.1',
  '30000156502': 'Кумены-Мирный',
  '1153973': 'Кумертау-Ишимбай',
  '140000000588': 'Кумли-Аксай',
  '20000022852': 'Курганинск-Лабинск',
  '1159369': 'Курдюм-Кологривовка I',
  '1153934': 'Курчанская-Анапа',
  '2350269': 'Куст 1024 УНГКМ - до КУ №5',
  '2350337': 'Куст 11-120 УНГКМ Ен-яхинская площадь - УКПГ-11В',
  '2350456': 'Куст 1613 УНГКМ Песцовая площадь - УКПГ-16',
  '2350453': 'Куст 1626 УНГКМ Песцовая площадь - УКПГ-16',
  '2350201': 'Куст 8-254 УНГКМ - УКПГ-8В',
  '2350203': 'Куст 8-256 УНГКМ - УКПГ-8В',
  '1153757': 'Ленинград-Выборг-Госграница I',
  '1153764': 'Ленинград-Выборг-Госграница II',
  '1258592': 'Ленинск-Знаменск-Ахтубинск',
  '1153885': 'Лог-Конный 1 нитка',
  '1153876': 'Лог-Михайловка I',
  '7528356': 'Лупинг 2 газопровода Грязовец-Выборг с целью замыкания второй нитки на участке «Грязовец-Выборг ',
  '160000002590': 'Лупинг ГО Дорогобуж',
  '160000363806': 'Лупинг на газопроводе-отводе Боровичи 1',
  '140000289406': 'МГ "Моздок-Казимагомед" на участке 610-623 км',
  '300000544583': 'МГ Ивацевичи-Долина I',
  '300000573288': 'МГ Ивацевичи-Долина II',
  '300000570778': 'МГ Кобрин-Брест-Госграница',
  '990007436356': 'МГ Минск-Вильнюс',
  '220003945472': 'МГ СХВ р/н оз. Гасси',
  '220003945485': 'МГ СХВ р/н оз. Синдинское',
  '220003945387': 'МГ СХВ р/н р. Анюй',
  '220000439090': 'МГ СХВ р/н р. Артемовка',
  '220000439056': 'МГ СХВ р/н р. Большая Уссурка',
  '220000439082': 'МГ СХВ р/н р. Уссури',
  '220000438724': 'МГ СХВ р/н р. Яй',
  '220003083633': 'МГ Сила Сибири р/н р. Алдан',
  '220003083600': 'МГ Сила Сибири р/н р. Амга',
  '220003117389': 'МГ Сила Сибири р/н р. Амур',
  '220003083661': 'МГ Сила Сибири р/н р. Гилюй 1',
  '220003083697': 'МГ Сила Сибири р/н р. Гилюй 2',
  '220003083990': 'МГ Сила Сибири р/н р. Лена',
  '220003083928': 'МГ Сила Сибири р/н р. Нюя 1',
  '220003083964': 'МГ Сила Сибири р/н р. Нюя 2',
  '220003083647': 'МГ Сила Сибири р/н р. Чульман',
  '220004144897': 'МГ Сила Сибири. Участок Ковыкта - Чаянда р/н р. Лена',
  '1154053': 'МГ Торжок-Долина',
  '1153724': 'МГ Торжок-Минск-Ивацевичи I',
  '1153725': 'МГ Торжок-Минск-Ивацевичи II',
  '1153726': 'МГ Торжок-Минск-Ивацевичи III',
  '1158396': 'МГ Тула-Торжок, РН, р. Волга, 433.7 км',
  '1157896': 'МГ Ямал-Европа',
  '3137268': 'МПК-2 м-ия Медвежье',
  '3816686': 'МПК-3 м-ия Медвежье',
  '7954775': 'Магистральный газопровод "Кази-Магомед-Моздок" на участке 600-610 км ',
  '220000081237': 'Магистральный газопровод Комсомольск-на-Амуре-Солнечная ГРС',
  '1154018': 'Магистральный газопровод от Астаховского м/р до Каменского участка',
  '1843472': 'Магистральный газопровод от Астаховского м/р до Каменского участка, р/н р.С.Донец, 1,0 км',
  '20000007775': 'Магистральный газопровод, Ду-1020  Кущёвская КС -Кущевское СПХГ',
  '1153795': 'Магнитогорск-Ишимбай ',
  '1154004': 'Майкоп-Некрасовская Уч.1',
  '1153946': 'Майкоп-Самурская-Сочи',
  '1158050': 'Макат - Северный Кавказ (лупинг)',
  '1153772': 'Макат-Северный Кавказ',
  '6492337': 'Макат-Северный Кавказ (лупинг)',
  '1254200': 'Малая Вишера',
  '160001909404': 'Маяковская',
  '98000000001863': 'Медвежье-Надым 1',
  '98000000001864': 'Медвежье-Надым 2',
  '1153664': 'Медвежье-Надым I',
  '1157843': 'Медвежье-Надым I, верх. р/н., р. Надым, км 96,5',
  '1157780': 'Медвежье-Надым I, нижн. р/н., р. Надым, км 96,5',
  '1153691': 'Медвежье-Надым II',
  '1157844': 'Медвежье-Надым II, верх. р/н., р. Надым, км 96,75',
  '1157781': 'Медвежье-Надым II, нижн. р/н., р. Надым, км 96,75',
  '290000032567': 'Межпромысловый ГГП-ЗТГП',
  '210000005366': 'Межпромысловый газовый коллектор Югид-Западный Соплеск, 1 этап',
  '3899584': 'Межпромысловый газопровод Етыпуровское ГМ-Вынгаяхинское ГМ',
  '290000613302': 'Межпромысловый газопровод УППГ-2 – УКПГ-3',
  '1154140': 'Межсистемная перемычка "Ямбург-Елец I" - "Ямбург-Елец II"',
  '1154141': 'Межсистемная перемычка "Ямбург-Зап.граница" - "Ямбург-Тула I"',
  '1154043': 'Миннибаево-Ижевск',
  '1154029': 'Миннибаево-Казань',
  '190000143551': 'Миннибаево-Казань (Подводящий газопровод к г.Казани)',
  '1153822': 'Мирное-Изобильное',
  '1153953': 'Митрофановская-Березанская',
  '1253132': 'Можга-Елабуга',
  '1158712': 'Моздок-Вознесеновское',
  '7260755': 'Моздок-Грозный',
  '1154042': 'Моздок-Невинномысск',
  '1153715': 'Моздок-Тбилиси',
  '1153803': 'Мокроус-Самара-Тольятти',
  '1153804': 'Мокроус-Самара-Тольятти (лупинг)',
  '2318563': 'Мокроус-Самара-Тольятти, р/н, р. Б.Иргиз, 126,9 км',
  '1159044': 'Мокроус-Самара-Тольятти, р/н, р. Самара, 341,65 км',
  '1157972': 'Муханово-Самара',
  '1159045': 'Муханово-Самара, 1 р/н, р. Бол. Кинель, 68,5 км',
  '1159046': 'Муханово-Самара, 2 р/н, р. Бол. Кинель,  68,5 км',
  '220000142928': 'Мыльджинское ГКМ - Вертикос',
  '1253940': 'Н.Камский промузел',
  '1153678': 'Н.Тура-Пермь I',
  '1158328': 'Н.Тура-Пермь I, р.Сылва, 222,8 км',
  '1153679': 'Н.Тура-Пермь II',
  '1153680': 'Н.Тура-Пермь III',
  '1158477': 'НГПЗ-Парабель I, р/н., р.Вах, 36,36км',
  '1158483': 'НГПЗ-Парабель I, р/н., р.Лымжа, 275,93км',
  '1158478': 'НГПЗ-Парабель I, р/н., р.Мишкин Саим, 66,95км',
  '1158479': 'НГПЗ-Парабель I, р/н., р.Обь-северная, 82,35км',
  '50001204177': 'НКП "Уренгой - Пур-пэ" р/н, р.Еваяха 20,7 км',
  '50001204182': 'НКП "Уренгой - Пур-пэ" р/н, р.Малый Ямсовей 50,9 км, р.Большой Ямсовей 55,7 км ',
  '1153685': 'Надым-Пунга I',
  '1157848': 'Надым-Пунга I, верх. р/н., р. Обь, км 522,5',
  '1157817': 'Надым-Пунга I, нижн. р/н., р. Обь, км 522,5',
  '1157804': 'Надым-Пунга I, р/н., р. Казым, км 384',
  '1157792': 'Надым-Пунга I, р/н., р. Лонг-Юган, км 111,5',
  '1157786': 'Надым-Пунга I, р/н., р. Лонг-Юган, км 44,4',
  '1153686': 'Надым-Пунга II',
  '1153667': 'Надым-Пунга IV',
  '1157819': 'Надым-Пунга IV,  р/н., р. Обь, км 522,5',
  '1157803': 'Надым-Пунга IV, р/н., р. Казым, км 384',
  '1157791': 'Надым-Пунга IV, р/н., р. Лонг-Юган, км 111,6',
  '1157841': 'Надым-Пунга IV, р/н., р. Малая Сосьва, км 556,2',
  '1153668': 'Надым-Пунга V (Уренгой-Грязовец)',
  '1157850': 'Надым-Пунга V (Уренгой-Грязовец), верх. р/н., р. Обь, км 525,5',
  '1157820': 'Надым-Пунга V (Уренгой-Грязовец), нижн. р/н., р. Обь, км 525,5',
  '1157799': 'Надым-Пунга V (Уренгой-Грязовец), р/н., р. Казым, км 381',
  '1157793': 'Надым-Пунга V (Уренгой-Грязовец), р/н., р. Лонг-Юган, км 114,6',
  '1154088': 'Надым-Пунга-II (лупинг)',
  '1153666': 'Надым-Пунга-Нижняя Тура III',
  '1581749': 'Надым-Пунга-Нижняя Тура III (реконструкция 1 этап II н.)',
  '1157847': 'Надым-Пунга-Нижняя Тура III, верх. р/н., р. Казым, км 384,2',
  '1157849': 'Надым-Пунга-Нижняя Тура III, верх. р/н., р. Обь, км 521,5',
  '1157802': 'Надым-Пунга-Нижняя Тура III, нижн. р/н., р. Казым, км 384,2',
  '1157818': 'Надым-Пунга-Нижняя Тура III, нижн. р/н., р. Обь, км 521,5',
  '1157790': 'Надым-Пунга-Нижняя Тура III, р/н., р. Лонг-Юган, км 111,5',
  '1157757': 'Надым-Пунга-Нижняя Тура III, р/н., р.Пелым, км 834,5',
  '1153825': 'Невинномысск-Моздок',
  '1254670': 'Невская Дубровка',
  '1154039': 'Некрасовская-Афипская',
  '1154005': 'Некрасовская-Березанская I',
  '1153923': 'Нефтегорский ГПЗ-Самара',
  '1158686': 'Нефтегорский ГПЗ-Самара, р/н, р.Самара, 18,02км',
  '50001204174': 'Нефтеконденсатопровод "Уренгой - Пур-Пэ"',
  '3679980': 'Нефтеп-д КоНГКМ УСНГ-УКПГ-10',
  '1158082': 'Нефтеп-д УКПГ-10-УКПГ-14 (участок от УКПГ-10 до ДКС-1)',
  '2707870': 'Нефтеп-д УКПГ-10-УКПГ-14 (участок от УКПГ-14 до ДКС-2)',
  '290000548609': 'Нефтепровод "Чаянда-ВСТО" Чаяндинского НГКМ',
  '290001024624': 'Нефтепровод "Чаянда-ВСТО" Чаяндинского НГКМ',
  '250000001506': 'Нефтепровод ЦПС 1 ЦПС-2. Уренгойское НГКМ.',
  '1153670': 'Нижневартовский ГПЗ-Парабель I',
  '1158157': 'Нижневартовский ГПЗ-Парабель II',
  '1154161': 'Нижневартовский ГПЗ-Сургутская ГРЭС (Локосовский ГПЗ-СГРЭС)',
  '160002363452': 'Новгород-2',
  '6492258': 'Новогрозный-Сержень-Юрт',
  '1153713': 'Новопсков-Аксай-Моздок - север',
  '1158401': 'Новопсков-Аксай-Моздок - север, р.Рассыпная, 96,07км',
  '1157906': 'Новопсков-Аксай-Моздок - юг',
  '1158188': 'Новопсков-Аксай-Моздок, р/н., р.Дон, 255 км, р. Черкасская, 260 км, р. Аксай, 262 км',
  '1153818': 'Новосибирск-Барнаул',
  '1158737': 'Новосибирск-Барнаул, р/н., р.Обь, 234,85 км',
  '1153828': 'Новосибирск-Кузбасс',
  '1252666': 'ОЭМК',
  '1159016': 'Обв. Г-д вокруг г.Н.Челны, р/н, р.Кама, 54 км',
  '1159167': 'Обв. г-д вокруг г. Н.Челны',
  '1158633': 'Обв. г-д вокруг г.Заинска',
  '1154020': 'Обвод г.Краснодара',
  '1841159': 'Озерки-Аткарск',
  '1255018': 'Озинки-Чижи',
  '1153962': 'Октябрьская-Ольгинская',
  '220000469715': 'Октябрьский - Хабаровск',
  '1153971': 'Октябрьское-Ольгинское-Чми',
  '1154050': 'Октябрьское-Оренбург',
  '1251762': 'Окуловка',
  '160001763021': 'Олонец',
  '1158496': 'Омск-Hовосибирск, р/н., р.Обь, 640,8км',
  '1158494': 'Омск-Hовосибирск, р/н., р.Омь, 100,5км',
  '1158495': 'Омск-Hовосибирск, р/н., р.Чаус, 622,26км',
  '1153723': 'Омск-Новосибирск',
  '1251682': 'Орел II, (п.Мезенка)',
  '1154028': 'Оренбург-Заинск',
  '1159418': 'Оренбург-Зап. гр. СССР ( Союз ), верхн. р/н р. Б. Узень,  507,6 км',
  '1159417': 'Оренбург-Зап. гр. СССР ( Союз ), нижн. р/н р. Б. Узень,  507,6 км',
  '1158804': 'Оренбург-Зап. гр. СССР (Союз), 1-ая р/н, р. Дон, 939 км',
  '1158924': 'Оренбург-Зап. гр. СССР (Союз), 1-я р/н, Волгоградское вдхр., 746,6 км',
  '1159329': 'Оренбург-Зап. гр. СССР (Союз), 2-ая р/н, р. Дон, 939 км',
  '1158925': 'Оренбург-Зап. гр. СССР (Союз), 2-я р/н, Волгоградское вдхр., 746,6 км',
  '1153699': 'Оренбург-Западная граница СССР ( Союз )',
  '1153700': 'Оренбург-Новопсков',
  '1158926': 'Оренбург-Новопсков, р/н, Волгоградское вдхр., 746,6 км',
  '2157948': 'Оренбург-Новопсков, р/н, р.Дон 939 км',
  '1153760': 'Оренбург-Самара',
  '1153978': 'Оренбургский ГПЗ-Совхозное ПХГ',
  '1252754': 'Орехово-Зуевский отвод',
  '1153898': 'Острогожск-Белоусово',
  '1153767': 'Острогожск-Шебелинка',
  '100001704529': 'Отвод к УРМЦ',
  '1153924': 'Отрадненский ГПЗ-Тольятти (АТЗ)',
  '1158692': 'Отрадненский ГПЗ-Тольятти (АТЗ), р/н, р.Б.Кинель, 12,45км',
  '1158693': 'Отрадненский ГПЗ-Тольятти (АТЗ), р/н, р.Сок, 72,89км',
  '110001255890': 'Оханск-Киров, р. Чепца, 144,7 км (нов)',
  '1158470': 'П/п ШФЛУ Сургут-Южный Балык, р/н., р.Обь, 3,85км, р.Стар.Обь, 7км',
  '1158469': 'П/п ШФЛУ Сургут-Южный Балык, р/н., р.Юганская Обь, 26 км',
  '2159502': 'ПГ I-III оч. (перемычка, р-н ГПЗ. Состоит из конечных участков гнг УКПГ-6-ГПЗ Iн. и гнг УКПГ-15-ГПЗ)',
  '30001424344': 'ПГУ Кировской ТЭЦ-3',
  '1154106': 'ПХГ- Армавир',
  '1153671': 'Парабель-Кузбасс I',
  '1158158': 'Парабель-Кузбасс II',
  '1252822': 'Парфино',
  '1158854': 'Пер-ка Гиагинская-Динская - Некрасовская-Березанская',
  '1581491': 'Пер-ка Елабуга-Новоменделеевск',
  '1154142': 'Пер-ка Игрим-Пунга (144 км) и Надым-Пунга II (529 км)',
  '1154145': 'Пер-ка КС Ивдель-КС Н.Ивдель',
  '1159201': 'Пер-ка Похвистнево-Самара III-ОГПЗ',
  '1154146': 'Пер-ка УКПГ 8,9-МГ Ямбург-Елец I (КС Ныда)',
  '1154156': 'Пер-ка Уренгой (УКПГ-15)-КС Ямбург',
  '1154143': 'Пер-ка Уренгой-Ужгород (433,1 км) - Уренгой-Новопсков (416 км)',
  '1154144': 'Пер-ка Уренгой-Ужгород (626,6 км) - Уренгой-Новопсков (615 км)',
  '1154158': 'Пер-ка ЦДКС-ГКС Уренгой-Надым (Пангоды)',
  '4033396': 'Пер-ка за КС Правохетинская Уренгой-Новопсков (194 км) и Уренгой-Ужгород (207 км)',
  '1158914': 'Пер-ка между КС Путятинская - Увязовское ПХГ и Ямбург-Тула 2',
  '1158913': 'Пер-ка между КС-4А (Яхрома) и переходом Грязовец-КГМО через канал им. Москвы',
  '90001314255': 'Пер-ка между Касимовская СПХГ - КГМО и КРП-16',
  '1154151': 'Пер-ка между г-ми Оренбург-Заинск и Совхозное-Оренбург',
  '1158894': 'Пер-ка между узлом редуцирования и Елец-Щекино',
  '1251440': 'Пер-ка на Похвистнево',
  '1581770': 'Пер-ка на вход КС Правохеттинская',
  '1153843': 'Первомайское-Сторожевка',
  '40000539957': 'Перевал Кударский(92,8км)-г.Цхинвал',
  '1256514': 'Перем-ка от ГО к г.Усть Джегута(49км) к г.Черкесску',
  '1582118': 'Перем. между г Буденновск и г.Буденновск-2',
  '80000008646': 'Перемычка I-II очередь ГКП',
  '1158980': 'Перемычка №2, 1нитка УКПГ-5-6 Уренгойское НГКМ',
  '40000077196': 'Перемычка ДКС-2 - КС-6',
  '40000141690': 'Перемычка МГ Камыш-Бурун-Ищёрская(87км) - Ищёрская-Моздок(21,7км)',
  '2248496': 'Перемычка Новое Хамидие-Дейское',
  '6492321': 'Перемычка Ставрополь-Грозный - Карабулак-Грозный',
  '1258962': 'Перемычка Ургала-Куваши',
  '1254820': 'Перемычка г.г. Баксан, Нальчик',
  '60000044825': 'Перемычка к МГ Муханово-Самара',
  '60000044843': 'Перемычка к МГ Похвистнево-Самара I п. Угорье',
  '1159271': 'Перемычка к МГ Похвистнево-Самара I п.Угорье, р/н, р.Самара',
  '30001040797': 'Перемычка м/у (Р/п м/у Починки-Грязовец (197,8 км) и Горький-Центр (100 км)) (0,2 км) и Расширение Горьковского промузла (0 км) ',
  '1154150': 'Перемычка м/у Ямбург-Тула I (2341 км) и Ямбург-Западная граница СССР (Прогресс) (2437,5 км)',
  '2162293': 'Перемычка между КС Изобильное-КС Рождественская (16.5 км) и отвод на ГРС-3 г.Ставрополь (0.01 км)',
  '1158574': 'Перемычка между Уренгой-Центр I  и КС-7А',
  '60000051736': 'Перемычка на ЗСК',
  '1553138': 'Перемычка на с.Тюлячи',
  '1158977': 'Переход трассой газ.коллектора через р.Хадуттэ-резервная нитка УКПГ13-15. Северо-Уренгойское НГКМ',
  '1255164': 'Пермская ГРЭС',
  '1258010': 'Пермская ГРЭС (2 нитка)',
  '1153683': 'Пермь-Горький I',
  '1158327': 'Пермь-Горький I, р.Кама, 43,5 км',
  '1158757': 'Пермь-Горький I, р/н р.Илеть, 574,8 км',
  '1153684': 'Пермь-Горький II',
  '1159021': 'Пермь-Горький II, р/н, р. Вятка, 415 км',
  '2250165': 'Песцовое м-ие',
  '1153759': 'Петровск-Елец',
  '1153775': 'Петровск-Елец (расширение)',
  '1158209': 'Петровск-Елец (расширение), р/н., р. Сосна, 591 км',
  '1153774': 'Петровск-Новопсков',
  '1158929': 'Петровск-Новопсков, р/н, р. Дон, 476 км',
  '1158928': 'Петровск-Новопсков, р/н, р. Хопер 318 км ',
  '40000083269': 'Петровско - Благодарненское газовое месторождение - Журавское',
  '1253390': 'Петрозаводск-Южная-1',
  '1153893': 'Печоро-Кожвинское ГКМ-Печорская ГРЭС',
  '1252412': 'Победа',
  '2158823': 'Подводящий г-д к Сосногорскому ГПЗ',
  '1259382': 'Подводящий газопровод к г.Казани',
  '210001272908': 'Подключающий газопровод ГП-1-0/28, р/н, р.Морды-Яха, 7,4 км',
  '210001595414': 'Подключающий газопровод ГП-3-0/28, р/н, р.Юнды-Яха, 8,58',
  '250000005262': 'Подключение УКПГ13 1н. Ен-Яхинская площадь Уренгойское НГКМ',
  '250000005270': 'Подключение УКПГ13, 2-я нитка. Ен-Яхинская площадь Уренгойское НГКМ',
  '250000787257': 'Подключение УКПГ1АС, 1и 2 нитки к МПК ',
  '1582001': 'Подпорожье',
  '1154154': 'Поляна-КСПХГ',
  '1581302': 'Поляна-Уфа',
  '1153920': 'Похвистнево-Бугуруслан',
  '1159277': 'Похвистнево-Бугуруслан, 1 р/н, р. Бол. Кинель, 22,45 км',
  '1158658': 'Похвистнево-Самара  I, р/н, р.Б.Кинель, 4,85 км',
  '1153718': 'Похвистнево-Самара I',
  '1159273': 'Похвистнево-Самара I, р/н, р.Кутулук',
  '1153720': 'Похвистнево-Самара III',
  '1158661': 'Похвистнево-Самара III, р/н, р.Б.Кинель, 4,94 км',
  '30000240417': 'Починки-Грязовец',
  '210000721939': 'Починки-Грязовец, р/н., р.Волга, 134,42/517 км',
  '1158405': 'Починки-Изобильное ССПХГ, р/н., пруд, 833,41км',
  '1158406': 'Починки-Изобильное ССПХГ, р/н., р. Б.Гок, 854,43км',
  '1158404': 'Починки-Изобильное ССПХГ, р/н., р. Большая Сандата, 821,8 км',
  '1158403': 'Починки-Изобильное ССПХГ, р/н., р. Маныч, 783,836 км',
  '1158402': 'Починки-Изобильное ССПХГ, р/н., р.Чепрак, 772,18 км',
  '1153737': 'Починки-Изобильное-ССПХГ (участок Петровск-Фролово-Изобильное)',
  '1153716': 'Починки-Пенза',
  '30000674016': 'Починки-Саранск',
  '1153779': 'Починки-Ярославль',
  '160001115077': 'Приозерск',
  '1157714': 'Продуктопровод  ШФЛУ Оренбург-Шкапово',
  '1157713': 'Продуктопровод ФУМ Оренбург-Салават  1н.',
  '1157706': 'Продуктопровод ШФЛУ Сургут-Юж.Балык',
  '1581614': 'Продуктопровод Шкапово-Туймазы',
  '1158663': 'Продуктопровод стабильного конденсата Сургутский ЗСК-НПС-З',
  '1258862': 'Промбаза "Сутузово"',
  '1253182': 'Псков',
  '1255180': 'Псковская птицефабрика',
  '1153694': 'Пунга-Вуктыл-Ухта I',
  '1158593': 'Пунга-Вуктыл-Ухта I, р/н., р. Печора, 415,5 км',
  '1157837': 'Пунга-Вуктыл-Ухта I, р/н., р. Северная Сосьва, км 150,3',
  '1153696': 'Пунга-Вуктыл-Ухта II',
  '1158689': 'Пунга-Вуктыл-Ухта II (лупинг)',
  '1158592': 'Пунга-Вуктыл-Ухта II, р/н., р. Ижма, 569,07 км',
  '1158594': 'Пунга-Вуктыл-Ухта II, р/н., р. Печора, 415,5 км',
  '1157838': 'Пунга-Вуктыл-Ухта II, р/н., р. Северная Сосьва, км 150,3',
  '1154089': 'Пунга-Вуктыл-Ухта-II (лупинг)',
  '1154090': 'Пунга-Вуктыл-Ухта-III (лупинг)',
  '1153697': 'Пунга-Ухта-Грязовец III',
  '1157839': 'Пунга-Ухта-Грязовец III (Уренгой-Грязовец), р/н., р. Северная Сосьва, км 150,3',
  '1158688': 'Пунга-Ухта-Грязовец III (лупинг)',
  '1158595': 'Пунга-Ухта-Грязовец III, р/н., р. Ижма, 569,07 км',
  '1158596': 'Пунга-Ухта-Грязовец III, р/н., р.Печора, 415,5 км',
  '1153731': 'Пунга-Ухта-Грязовец IV (Уренгой-Грязовец)',
  '1158626': 'Пунга-Ухта-Грязовец IV, р/н., р. Виледь, 437,07 км',
  '1158629': 'Пунга-Ухта-Грязовец IV, р/н., р. Вымь, 205,5 км',
  '1158630': 'Пунга-Ухта-Грязовец IV, р/н., р. Вычегда, 299,9 км',
  '1158631': 'Пунга-Ухта-Грязовец IV, р/н., р. С. Двина, 487,4 км',
  '1158632': 'Пунга-Ухта-Грязовец IV, р/н., р. Сухона, 842 км',
  '1259302': 'Пунгинская СПХГ',
  '150000191912': 'Пуртазовская КС-Новоуренгойская ГКС-2',
  '150000258297': 'Пуртазовская КС-Новоуренгойская ГКС-2 лупинг',
  '160000377350': 'Пыталово',
  '1252944': 'Раменский отвод',
  '1153956': 'Расшеватское-Рождественская КС',
  '1259168': 'Расширение Горьковского промузла',
  '70000323163': 'Ржакса-Инжавино',
  '1154017': 'Ростов-Майкоп I',
  '1154009': 'Ростов-Майкоп II',
  '1254152': 'Рязанская ГРЭС, Новомичуринск',
  '1158747': 'САЦ III (АлГай-Острогожск), р/н, Волгоградское вдхр., 244,8 км',
  '1158749': 'САЦ III (АлГай-Острогожск), р/н, р. Хопер, 482 км',
  '1154137': 'САЦ-II (лупинг, 1134-1145)',
  '1154112': 'САЦ-II (лупинг, 1290-1339)',
  '1153842': 'САЦ-Степное I',
  '1153840': 'САЦ-Степное III',
  '1153832': 'СП Зап.Рыбушка-СП Вост.Рыбушка',
  '1581476': 'СП-22-Озинки-Перелюб',
  '1153710': 'СРТО-Омск',
  '1158733': 'СРТО-Омск,  р/н., р.Иртыш, 1691,5 км',
  '1158448': 'СРТО-Омск, р/н.,  р. Лосьеган, 352,5 км, р. Мочканеган, 355,1 км',
  '1158446': 'СРТО-Омск, р/н., р. Аган, 334,5 км, р. Егурьеган, 340,8 км',
  '1158493': 'СРТО-Омск, р/н., р.Ишим, 1488 км',
  '1153659': 'СРТО-Торжок',
  '210000058387': 'СРТО-Торжок (лупинг)2466,6(1129,4)км-2515,87(1180,52)км',
  '3681236': 'СРТО-Торжок I',
  '3204266': 'СРТО-Торжок II',
  '3681284': 'СРТО-Торжок III',
  '1158703': 'СРТО-Торжок, р/н,  р. Печора, 1152,5/416 км',
  '2323200': 'СРТО-Торжок, р/н., р. Ижма, 1307,8 км/569 км',
  '210000057467': 'СРТО-Торжок, р/н., р. С. Двина, 1813.9км/487км',
  '1158575': 'СРТО-Торжок, р/н., р. Северная Сосьва, км 885,5',
  '1581623': 'СРТО-Торжок, р/н., р.Обь, 675км',
  '210000054013': 'СРТО-Торжок, р/н., р.Сухона, 2169км/842км ',
  '2322971': 'СРТО-Торжок, р/н., р.Ухта,1347 км/39 км',
  '210000003222': 'СРТО-Торжок,р/н р.Виледь, 1764 км/437,07км',
  '1153662': 'СРТО-Урал',
  '1159166': 'СРТО-Урал II (реконструкция 1 этап I н.)',
  '1581305': 'СРТО-Урал II (реконструкция 1 этап I н..)',
  '1153781': 'СРТО-Урал-II',
  '1154091': 'СРТО-Урал-II (лупинг)',
  '1157764': 'СРТО-Урал-II, р/н., р. Лобва, км 532,5',
  '1157827': 'СРТО-Урал-II, р/н., р. Лозьва, км 362',
  '1157831': 'СРТО-Урал-II, р/н., р. Сосьва, км 413,2',
  '1157836': 'СРТО-Урал-II, р/н., р. Тура, км 599,5',
  '1157766': 'СРТО-Урал-II, р/н., р. Эсс, км 191,2',
  '1157763': 'СРТО-Урал-II, р/н., р.Ивдель, 369,5 км',
  '1157765': 'СРТО-Урал-II, р/н., р.Пелым, км 274,5',
  '1153702': 'Саратов-Горький',
  '1153701': 'Саратов-Москва',
  '1159428': 'Саратов-Москва, р/н р. Ворона, 236,2 км',
  '1253964': 'Сафоново',
  '220000397543': 'Сахалин-Хабаровск-Владивосток',
  '220000398213': 'Сахалин-Хабаровск-Владивосток, р/н пролив Невельского',
  '1153674': 'Свердловск-Н.Тагил (Б-Урал I)',
  '1153790': 'Свердловск-Сысерть (Б-Урал II)',
  '1254330': 'Светлогорск',
  '1254724': 'Светогорск',
  '1154040': 'Сев.районы Дагестана-Камыш-Бурун',
  '1153771': 'Северный Кавказ-Закавказье',
  '1154111': 'Северный Кавказ-Центр (СКЦ)',
  '3209251': 'Северный-Кавказ-Центр (СКЦ) - юг',
  '220000142882': 'Северо-Васюганское ГКМ - врезка в МГ НВГПЗ-Парабель',
  '160000000850': 'Северо-Европейский газопровод-1',
  '160000521981': 'Северо-Европейский газопровод-2',
  '160003211968': 'Северо-Европейский газопровод-3',
  '160003211969': 'Северо-Европейский газопровод-4',
  '1254884': 'Северо-Западная ТЭЦ',
  '1252092': 'Сердобск-Ртищево',
  '6492293': 'Сержень-Юрт-Алхазурово',
  '1154036': 'Серпухов-Воскресенск (КГМО-II)',
  '1153763': 'Серпухов-Ленинград',
  '990007704723': 'Сила Сибири',
  '220002946965': 'Сила Сибири 1985,5/0-180,3',
  '7177415': 'Сила Сибири. Участок Ковыкта – Чаянда',
  '1254850': 'Смоленск',
  '1254444': 'Смоленская ГРЭС',
  '1581176': 'Советск',
  '100000131267': 'Совхозное ПХГ - Оренбургский ГПЗ',
  '1153810': 'Совхозное СПХГ-Канчуринская СПХГ',
  '160001115078': 'Сосново',
  '160002354356': 'Сосновый Бор',
  '1258896': 'Сосногорский ГПЗ- ГРС Крутянская',
  '1153738': 'Средняя Азия-Центр I',
  '1153733': 'Средняя Азия-Центр II',
  '3143190': 'Средняя Азия-Центр II-II',
  '1153777': 'Средняя Азия-Центр III (АлГай-Острогожск)',
  '1153734': 'Средняя Азия-Центр III (АлГай-Петровск)',
  '1153740': 'Средняя Азия-Центр IV',
  '1153732': 'Средняя Азия-Центр IV-1',
  '1153735': 'Средняя Азия-Центр IV-2',
  '1153741': 'Средняя Азия-Центр V',
  '1158697': 'Ст. Бинарадка-Дмитровград-Ульяновск, р/н, Куйбышевское в/х, 158,9км',
  '1158696': 'Ст. Бинарадка-Дмитровград-Ульяновск, р/н, р.Черемшан, 89,9км',
  '1153712': 'Ставрополь-Грозный I',
  '1153752': 'Ставрополь-Грозный II',
  '1153742': 'Ставрополь-Москва I',
  '1255238': 'Ставропольская ГРЭС',
  '1154047': 'Старая Бинарадка-Димитровград-Ульяновск',
  '60000633836': 'Старая Бинарадка-Димитровград-Ульяновск, р/н, Куйбышевское вдхр. ',
  '1254332': 'Старая Русса',
  '1255084': 'Старица',
  '1159006': 'Староминская- Куликовская',
  '1154108': 'Староминская-Ейск (лупинг)',
  '70002865748': 'Степное - Балаково (новый)',
  '1154071': 'Степное-Балаково (лупинг)',
  '1153914': 'Степное-Сторожевка',
  '1154068': 'Степное-Сторожевка (лупинг)',
  '1154061': 'Сторожевка-Елшанская СПХГ I',
  '1154062': 'Сторожевка-Елшанская СПХГ II',
  '1154063': 'Сторожевка-Елшанская СПХГ III',
  '1154066': 'Сторожевка-Красноармейск',
  '1153830': 'Сторожевка-П.Умет I',
  '1153831': 'Сторожевка-П.Умет II',
  '1153829': 'Сторожевка-Петровск',
  '3139365': 'Сторожевка-Петровск (лупинг)',
  '1255380': 'Сургутская ЗСК, 2н.',
  '1581557': 'Сюмси-1',
  '1255210': 'Сясьский ЦБК',
  '40001050806': 'Т/П от газопровода-отвода на г. Зеленокумск до КС "Георгиевская" ',
  '100000870916': 'Т/п Между Бухара - Урал (2183,9 км) и Свердловск - Сысерть (38 км)',
  '110000003483': 'Т/п между (т/п между СРТО-Урал и Ямбург-Поволжье, 1704,9 км) и (Ямбург-Елец II, р/н., р.Сылва, 1704,55 км), 1705 км',
  '160002354722': 'Т/п между Белоусово-Ленинград (730.95 км) и Лаголово (новый) (0 км)',
  '210000007414': 'Т/п между Вуктыл-Ухта II (35 км) и Пунга-Вуктыл-Ухта I (415 км)',
  '1159218': 'Т/п между МГ Уренгой-Новопсков и Уренгой-Петровск, 2612 км',
  '110001140659': 'Т/п между Межсистемная перемычка "Ямбург-Зап.граница" - "Ямбург-Тула I" и Ямбург-Тула-1, 42 км',
  '240000420535': 'Т/п между СРТО-Торжок (686,8км) и Уренгой-петровск (745,7км)',
  '160003212694': 'Т/п между Северо-Европейский газопровод-4 (795.167 км) и Кохтла-Ярве-Ленинград-2 (новый) (83 км)',
  '3176814': 'Т/п между Тула-Торжок (512.79 км) и Белоусово-Ленинград (259.1 км)',
  '110000002595': 'Т/п между Уренгой-Ужгород (лупинг) 1821 км и Ямбург-Западная Граница (лупинг) 1960 км, 1846,9 км',
  '2162053': 'Т/п между Уренгой-Ужгород и Уренгой-Ужгород (лупинг) 1821 км, 1846,9 км',
  '3176781': 'Т/п между Ухта-Торжок-2 (1332.8 км) и Тула-Торжок (512.75 км)',
  '110000003445': 'Т/п между Ямбург-Елец II, р/н., р.Сылва, 1704,39 км и Ямбург-Западная граница СССР (Прогресс), 1703.9 км',
  '110000003500': 'Т/п между Ямбург-Елец II, р/н., р.Сылва, 1704,39 км и Ямбург-Западная граница СССР (Прогресс), 1705.1 км',
  '210000007422': 'Т/п между р/н Вуктыл-Ухта II (37км) и Пунга-Вуктыл-Ухта I (417км)',
  '20000637950': 'ТП Россия-Турция - перемычка КС Кубанская-КС Кореновская',
  '20000639198': 'ТП Южно-европейский МГ - перемычка КС Кубанская-КС Кореновская',
  '1153993': 'Таганрог-Амвросиевка II',
  '160001912014': 'Талаховская ТЭС',
  '1157108': 'Тамбов-Котовск-Уварово',
  '1153989': 'Темрюк-Тамань',
  '70000036232': 'Терновка-Жердевка',
  '1254656': 'Тетьково',
  '1581416': 'Технологическая пер-ка между Казань-5, ТЭЦ-3 и Казань, ГРС-2',
  '1253918': 'Тихвин',
  '990007704732': 'Токаревка-Жердевка',
  '70000389775': 'Токаревка-Мордово',
  '1153889': 'Торжок-Валдай',
  '6946316': 'Трубопровод газов деэтанизации с УСК на Уренгойский ЗПКТ',
  '6946246': 'Трубопровод деэтанизированного конденсата с УСК на врезку в МК "Уренгой-Сургут"',
  '6946253': 'Трубопровод деэтанизированного конденсата с УСК на врезку в МК Уренгой-Сургут, р/н. через водную преграду',
  '2248284': 'Трубопровод нестабильного конденсата УКПГ 8 В- УКПГ 5В-УПКТ. Уренгойское НГКМ',
  '1153974': 'Туймазы-Уфа',
  '1154054': 'Тула-Торжок',
  '1158246': 'Тула-Торжок, р/н., Рузское водохранилище, 359,6 км',
  '1154052': 'Тула-Шостка-Киев',
  '1158242': 'Тула-Шостка-Киев, р/н., р. Ока, 87 км',
  '220000285324': 'УКПГ Нижнеквакчикского ГКМ-АГРС г.Петропавловск-Камчатский',
  '1256464': 'УКПГ-2 - АГРС-2',
  '180000045879': 'УППГ 10- УКПГ 9 Ду 1000 ',
  '180000431620': 'УППГ 2В - УКПГ 1В 2 нитка Ду 500',
  '180000000458': 'УППГ 2В -УКПГ 1В 1нитка Ду 500',
  '180000000451': 'УППГ 3В - УКПГ 1В 1нитка  Ду 500',
  '180000000455': 'УППГ 3В - УКПГ 1В 2 нитка  Ду 500',
  '180000000462': 'УППГ 4А- УКПГ 4 Ду 500',
  '180000000466': 'УППГ 4А- УКПГ4 Ду 700',
  '180000802773': 'УППГ4А - УКПГ4 Ду 700 2н',
  '1158033': 'Увязовское ПХГ-Касимовское ПХГ',
  '8474639': 'Увязовское ПХГ-Касимовское ПХГ (лупинг)',
  '1252178': 'Ударник',
  '1153663': 'Уренгой-Надым I',
  '1157842': 'Уренгой-Надым I, верх.р/н., р. Надым, км 207,5',
  '1157779': 'Уренгой-Надым I, нижн. р/н., р. Надым, км 207,5',
  '1153695': 'Уренгой-Надым II (Уренгой-Грязовец)',
  '1153704': 'Уренгой-Новопсков',
  '1154136': 'Уренгой-Новопсков (лупинг)',
  '1158672': 'Уренгой-Новопсков, 1-я р/н, Куйбышевское в/х, 2434,87 км',
  '1158673': 'Уренгой-Новопсков, 2-я р/н, Куйбышевское в/х, 2434,87 км',
  '1158675': 'Уренгой-Новопсков, 3-я р/н, Куйбышевское в/х, 2432,87 км',
  '1158326': 'Уренгой-Новопсков, р.Койва, 1463 км',
  '1158319': 'Уренгой-Новопсков, р.Чусовая, 1474,75 км',
  '1158931': 'Уренгой-Новопсков, р/н, р. Дон, 3214 км',
  '1158671': 'Уренгой-Новопсков, р/н, р.Сок, 2296,25км',
  '1159434': 'Уренгой-Новопсков, р/н, р.Хопёр 3055 км',
  '1157800': 'Уренгой-Новопсков, р/н., р. Казым, км 598,1',
  '1157828': 'Уренгой-Новопсков, р/н., р. Лозьва, км 1130,55',
  '1157788': 'Уренгой-Новопсков, р/н., р. Лонг-Юган, км 263',
  '1157794': 'Уренгой-Новопсков, р/н., р. Лонг-Юган, км 331,6',
  '1157821': 'Уренгой-Новопсков, р/н., р. Обь, км 743,2',
  '170000046049': 'Уренгой-Новопсков,р/н.,р.Белая.1921,3 км.',
  '1153783': 'Уренгой-Петровск',
  '1154093': 'Уренгой-Петровск (лупинг)',
  '1158669': 'Уренгой-Петровск, 1-я р/н, Куйбышевское в/х, 2434,87 км',
  '1158670': 'Уренгой-Петровск, 2-я р/н, Куйбышевское в/х, 2434,87 км',
  '1158674': 'Уренгой-Петровск, 3-я р/н, Куйбышевское в/х, 2434,87 км',
  '1157846': 'Уренгой-Петровск, верх. р/н., р. Надым, км 208,45',
  '1157851': 'Уренгой-Петровск, верх. р/н., р. Обь, км 739,5',
  '1157783': 'Уренгой-Петровск, нижн. р/н., р. Надым, км 208,45',
  '1157822': 'Уренгой-Петровск, нижн. р/н., р. Обь, км 739,5',
  '1158341': 'Уренгой-Петровск, р.Койва, 1459,95 км',
  '1158320': 'Уренгой-Петровск, р.Чусовая, 1472,75 км',
  '1158668': 'Уренгой-Петровск, р/н, р.Сок, 2296,25км',
  '1158138': 'Уренгой-Петровск, р/н., р. Ик, 2062,5 км',
  '1157801': 'Уренгой-Петровск, р/н., р. Казым, км 597,9',
  '1157835': 'Уренгой-Петровск, р/н., р. Каква, км 1261,45',
  '1157829': 'Уренгой-Петровск, р/н., р. Лозьва, км 1125,8',
  '1157789': 'Уренгой-Петровск, р/н., р. Лонг-Юган, км 260,8',
  '1157795': 'Уренгой-Петровск, р/н., р. Лонг-Юган, км 329',
  '170000045926': 'Уренгой-Петровск,р/н.,р.Белая,1921,3 км.',
  '1153705': 'Уренгой-Ужгород',
  '1154122': 'Уренгой-Ужгород (лупинг)',
  '1154086': 'Уренгой-Ужгород (лупинг), 1508 км',
  '1154121': 'Уренгой-Ужгород (лупинг), 1657 км',
  '1154123': 'Уренгой-Ужгород (лупинг), 1821 км',
  '1158315': 'Уренгой-Ужгород, р.Сылва, 1594,87 км',
  '1158324': 'Уренгой-Ужгород, р.Чусовая, 1480,35 км',
  '1158767': 'Уренгой-Ужгород, р/н р. Волга, 2242,6 км',
  '1158769': 'Уренгой-Ужгород, р/н р. Мокша, 2584,5 км',
  '1158768': 'Уренгой-Ужгород, р/н р. Сура, 2368,6 км',
  '1159022': 'Уренгой-Ужгород, р/н, р. Вятка, 2028,25 км',
  '1157807': 'Уренгой-Ужгород, р/н., р. Амня, км 601,3',
  '1157797': 'Уренгой-Ужгород, р/н., р. Казым, км 566,1',
  '1157824': 'Уренгой-Ужгород, р/н., р. Лозьва, км 1143,95',
  '1157777': 'Уренгой-Ужгород, р/н., р. Надым, км 218,9',
  '1157773': 'Уренгой-Ужгород, р/н., р. Правая Хетта, км 204,2',
  '1157814': 'Уренгой-Ужгород, р/н., р.Обь, км 760, пр. Алешкинская, км 764',
  '1153717': 'Уренгой-Центр I',
  '1153782': 'Уренгой-Центр I (лупинг)',
  '1158311': 'Уренгой-Центр I, р.Кама, 1850,6 км',
  '1158316': 'Уренгой-Центр I, р.Сылва, 1593,68 км',
  '1158321': 'Уренгой-Центр I, р.Чусовая, 1480,35км',
  '1158772': 'Уренгой-Центр I, р/н р. Сура, 2370,6 км',
  '1158646': 'Уренгой-Центр I, р/н., р.Вятка, 2030,95 км',
  '1157815': 'Уренгой-Центр I, р/н., р.Обь, км 754, пр. Алешкинская, км 759',
  '1153722': 'Уренгой-Центр II',
  '1154124': 'Уренгой-Центр II (лупинг), 1482 км',
  '1158322': 'Уренгой-Центр II, р.Чусовая, 1481,5 км',
  '1157798': 'Уренгой-Центр II, р/н., р. Казым, км 566,6',
  '1157825': 'Уренгой-Центр II, р/н., р. Лозьва, км 1143',
  '1157778': 'Уренгой-Центр II, р/н., р. Надым, км 218,5',
  '1157774': 'Уренгой-Центр II, р/н., р. Правая Хетта, км 203,8',
  '1158190': 'Уренгой-Центр II, р/н., р. Цна, 2738,3 км',
  '1157808': 'Уренгой-Центр II, р/н., р.Амня, км 602,1',
  '1157816': 'Уренгой-Центр II, р/н., р.Обь, км 755,5, пр. Алешкинская, км 760',
  '1153750': 'Уренгой-Челябинск I',
  '1158424': 'Уренгой-Челябинск I, I рез.н.,  пр-ка Лангепас, 627,1 км, оз. Ганжеева, 630 км, р. Обь, 639,8 км, пр-ка Локосовская, 642,2 км,',
  '1158472': 'Уренгой-Челябинск I, II рез. н.,  пр-ка Лангепас, 627,1 км, оз. Ганжеева, 630 км, р. Обь, 639,8 км, пр-ка Локосовская, 642,2 км,',
  '1158429': 'Уренгой-Челябинск I, верх. рез. н., протока Иртыш, 1165,1 км, р. Иртыш, 1168,23 км',
  '1158473': 'Уренгой-Челябинск I, нижняя р/н., протока Иртыш, 1165,1 км, р. Иртыш, 1168,23 км',
  '1158423': 'Уренгой-Челябинск I, р/н., р.Аган, 586км',
  '1158431': 'Уренгой-Челябинск I, р/н., р.Тура, 1376 км, р. Дуван, 1388,05 км, р. Пышма, 1395,95 км',
  '1153721': 'Уренгой-Челябинск II',
  '1581269': 'Уренгой-Челябинск II лупинг',
  '1158436': 'Уренгой-Челябинск II, I рез. н., р. Лосьеган, 601,03 км, р. Мочканеган, 605,1 км,  пр-ка Лангепас, 627,07 км,  оз. Ганжеева, 630,15 км, р. Обь, 639,8 км, пр-ка Локосовская, 642,15 км',
  '1158474': 'Уренгой-Челябинск II, II рез. н., р. Лосьеган, 601,03 км, р. Мочканеган, 605,1 км,  пр-ка Лангепас, 627,07 км,  оз. Ганжеева, 630,15 км, р. Обь, 639,8 км, пр-ка Локосовская, 642,15 км',
  '1158441': 'Уренгой-Челябинск II, верхняя р/н., протока Иртыш, 1165,13 км, р. Иртыш, 1168,23 км',
  '1158475': 'Уренгой-Челябинск II, нижняя р/н., протока Иртыш, 1165,13 км, р. Иртыш, 1168,23 км',
  '1158432': 'Уренгой-Челябинск II, р/н., р. Тыдыотта, 112,47 км,  р. Салетьяха Старица 2, 112,84 км, р. Салетьяха, 113,33 км,',
  '1158435': 'Уренгой-Челябинск II, р/н., р.Аган, 586км',
  '1158443': 'Уренгой-Челябинск II, р/н., р.Тура, 1376 км, р. Дуван, 1388,01 км, р. Пышма, 1395,95 км',
  '1158507': 'Уренгой-Челябинск II, р/н., старица р. Исеть, 1589,6 км,  р. Исеть, 1591,5 км',
  '1153834': 'Урицкая КС-Жирновск-Кологривовка',
  '1153845': 'Урицкое-Горючка',
  '160003247885': 'Усть-Луга',
  '1153728': 'Ухта-Торжок I',
  '210000662402': 'Ухта-Торжок I (Ухта-Грязовец)',
  '1158599': 'Ухта-Торжок I, р/н., р. Виледь, 437,07 км',
  '1158600': 'Ухта-Торжок I, р/н., р. Волга-1, 1058,46 км',
  '1158601': 'Ухта-Торжок I, р/н., р. Волга-2, 1098,7 км',
  '1158602': 'Ухта-Торжок I, р/н., р. Вымь, 205,5 км',
  '1158603': 'Ухта-Торжок I, р/н., р. Вычегда, 299,9 км',
  '1158604': 'Ухта-Торжок I, р/н., р. С. Двина, 487,4 км',
  '1158605': 'Ухта-Торжок I, р/н., р. Сухона, 842 км',
  '1158606': 'Ухта-Торжок I, р/н., р. Уфтюга, 653,1 км',
  '1153729': 'Ухта-Торжок II',
  '210000668599': 'Ухта-Торжок II (Ямал)',
  '210000060762': 'Ухта-Торжок II (лупинг)',
  '1158608': 'Ухта-Торжок II, р/н., р. Виледь, 437,07 км',
  '1158609': 'Ухта-Торжок II, р/н., р. Волга-1, 1058,46 км',
  '1158610': 'Ухта-Торжок II, р/н., р. Волга-2, 1098,7 км',
  '1158611': 'Ухта-Торжок II, р/н., р. Вымь, 205,5 км',
  '1158612': 'Ухта-Торжок II, р/н., р. Вычегда, 299,9 км',
  '1158613': 'Ухта-Торжок II, р/н., р. С. Двина, 487,4 км',
  '1158614': 'Ухта-Торжок II, р/н., р. Сухона, 842 км',
  '1158615': 'Ухта-Торжок II, р/н., р. Уфтюга, 653,1 км',
  '1153730': 'Ухта-Торжок III',
  '1158617': 'Ухта-Торжок III, р/н., р. Виледь, 437,07 км',
  '1158618': 'Ухта-Торжок III, р/н., р. Волга-1, 1058,46 км',
  '1158619': 'Ухта-Торжок III, р/н., р. Волга-2, 1098,7 км',
  '1158620': 'Ухта-Торжок III, р/н., р. Вымь, 205,5 км',
  '1158621': 'Ухта-Торжок III, р/н., р. Вычегда, 299,9 км',
  '1158622': 'Ухта-Торжок III, р/н., р. С. Двина, 487,47 км',
  '1158623': 'Ухта-Торжок III, р/н., р. Сухона, 842 км',
  '1158624': 'Ухта-Торжок III, р/н., р. Уфтюга, 653,1 км',
  '160002354361': 'Фосфорит 2 (новый)',
  '1253686': 'Фосфоритный рудник',
  '1158797': 'Фролово-Изобильное ("Голубой Поток"), р/н, ВДСК, 469 км',
  '1158795': 'Фролово-Изобильное ("Голубой Поток"), р/н, р. Грачи, 415 км',
  '1158796': 'Фролово-Изобильное ("Голубой Поток"), р/н, р. Карповка 2, 458 км',
  '1153703': 'Челябинск-Петровск',
  '1158678': 'Челябинск-Петровск, 1-я р/н, Куйбышевское в/х, 920,87км',
  '1158679': 'Челябинск-Петровск, 2-я р/н, Куйбышевское в/х, 920,87км',
  '1158680': 'Челябинск-Петровск, 3-я р/н, Куйбышевское в/х, 920,87км',
  '1158676': 'Челябинск-Петровск, верх. р/н, р.Сок, 783,05 км',
  '1158151': 'Челябинск-Петровск, верх. р/н., р. Ик, 549,9 км',
  '1158677': 'Челябинск-Петровск, нижн. р/н, р.Сок, 783,05 км',
  '1159012': 'Челябинск-Петровск, нижн. р/н., р. Ик, 549,9 км',
  '1158142': 'Челябинск-Петровск,верх. р/н.,р.Ай,216.2км',
  '170000044780': 'Челябинск-Петровск,верх.р/н,р.Белая 408,7 км.',
  '1158144': 'Челябинск-Петровск,верх.р/н.,р.Уфа,322,8 км',
  '170000045587': 'Челябинск-Петровск,нижн. р/н, р.Белая 408,7 км.',
  '1158143': 'Челябинск-Петровск,нижн. р/н.,р.Ай,216.2км',
  '1158145': 'Челябинск-Петровск,нижн. р/н.,р.Уфа,322,8 км',
  '160001327230': 'Черняховск',
  '1158333': 'Чусовая-Березники-Соликамск, 1н., р. Косьва, 73,15 км',
  '1158334': 'Чусовая-Березники-Соликамск, 1н., р. Усьва, 48,5 км',
  '110000929198': 'Чусовая-Березники-Соликамск, 2н(новая), р. Вильва, 16,57 км ',
  '1158332': 'Чусовая-Березники-Соликамск, 2н., р. Вильва, 17,45 км',
  '1158335': 'Чусовая-Березники-Соликамск, 2н., р. Косьва, 73,15 км',
  '1154116': 'ШБКБ (лупинг)',
  '1154117': 'ШБКБ (лупинг)',
  '9036065': 'ШБКБ (реконструкция)',
  '1153754': 'Шебелинка-Белгород-Курск-Брянск',
  '1153739': 'Шебелинка-Острогожск',
  '1253900': 'Шекснинская п/ф-ка',
  '1153975': 'Шкапово-Ишимбай',
  '2250587': 'Шлейф 1 IV цеха КС Острогожск',
  '80000162682': 'Шлейф Скв. №540',
  '80000174135': 'Шлейф скв 911',
  '3129008': 'Шлейф скв №101 Астраханское ГКМ - УППГ-2',
  '80000010899': 'Шлейф скв №102 Астраханское ГКМ - УППГ-2',
  '3129006': 'Шлейф скв №104 Астраханское ГКМ - УППГ-1',
  '3128986': 'Шлейф скв №107 Астраханское ГКМ - УППГ-1',
  '3128979': 'Шлейф скв №110 Астраханское ГКМ - УППГ-1',
  '3128980': 'Шлейф скв №112 Астраханское ГКМ - УППГ-1',
  '3128993': 'Шлейф скв №113 Астраханское ГКМ - УППГ-1',
  '3128977': 'Шлейф скв №115 Астраханское ГКМ - УППГ-1',
  '3129002': 'Шлейф скв №117 Астраханское ГКМ - УППГ-1',
  '3129066': 'Шлейф скв №1РФ Астраханское ГКМ - УППГ-4',
  '3129033': 'Шлейф скв №204 Астраханское ГКМ - УППГ-2',
  '3129030': 'Шлейф скв №209 Астраханское ГКМ - УППГ-2',
  '3129039': 'Шлейф скв №2091 Астраханское ГКМ - УППГ-2',
  '80000012879': 'Шлейф скв №2100',
  '3129026': 'Шлейф скв №216 Астраханское ГКМ - УППГ-2',
  '3129025': 'Шлейф скв №218 Астраханское ГКМ - УППГ-2',
  '3129024': 'Шлейф скв №219 Астраханское ГКМ - УППГ-2',
  '80000012882': 'Шлейф скв №221',
  '3129060': 'Шлейф скв №224 Астраханское ГКМ - УППГ-4',
  '3129037': 'Шлейф скв №250 Астраханское ГКМ - УППГ-2',
  '3129029': 'Шлейф скв №253 Астраханское ГКМ - УППГ-2',
  '3129031': 'Шлейф скв №263 Астраханское ГКМ - УППГ-2',
  '3129063': 'Шлейф скв №3ГФ Астраханское ГКМ - УППГ-4',
  '3129043': 'Шлейф скв №401 Астраханское ГКМ - УППГ-3А',
  '3129044': 'Шлейф скв №402 Астраханское ГКМ - УППГ-3А',
  '3129061': 'Шлейф скв №404 Астраханское ГКМ - УППГ-4',
  '3129067': 'Шлейф скв №411 Астраханское ГКМ - УППГ-4',
  '3129068': 'Шлейф скв №413 Астраханское ГКМ - УППГ-4',
  '3129053': 'Шлейф скв №430 Астраханское ГКМ - УППГ-4',
  '3129062': 'Шлейф скв №431Д Астраханское ГКМ - УППГ-4',
  '3129057': 'Шлейф скв №437 Астраханское ГКМ - УППГ-4',
  '80000165513': 'Шлейф скв №4438',
  '3129059': 'Шлейф скв №451 Астраханское ГКМ - УППГ-4',
  '80000010247': 'Шлейф скв №466 Астраханское ГКМ - УППГ-4',
  '3128987': 'Шлейф скв №51   Астраханское ГКМ - УППГ-1',
  '80000174323': 'Шлейф скв №545',
  '3129005': 'Шлейф скв №546 Астраханское ГКМ - УППГ-1',
  '3128994': 'Шлейф скв №56Д Астраханское ГКМ - УППГ-1',
  '3129080': 'Шлейф скв №601 Астраханское ГКМ - УППГ-6',
  '80000200869': 'Шлейф скв №606 Астраханское ГКМ - УППГ-6',
  '3129071': 'Шлейф скв №609 Астраханское ГКМ - УППГ-6',
  '3129077': 'Шлейф скв №616 Астраханское ГКМ - УППГ-6',
  '3129081': 'Шлейф скв №617 Астраханское ГКМ - УППГ-6',
  '3129075': 'Шлейф скв №621 Астраханское ГКМ - УППГ-6',
  '3129020': 'Шлейф скв №63 Астраханское ГКМ - УППГ-2',
  '80000013709': 'Шлейф скв №6833 Астраханское ГКМ - УППГ-6',
  '3129048': 'Шлейф скв №701 Астраханское ГКМ - УППГ-3А',
  '80000165277': 'Шлейф скв №705',
  '3129051': 'Шлейф скв №708 Астраханское ГКМ - УППГ-3А',
  '80000174332': 'Шлейф скв №710',
  '80000262259': 'Шлейф скв №711',
  '80000015209': 'Шлейф скв №715 ',
  '3129045': 'Шлейф скв №717 Астраханское ГКМ - УППГ-3А',
  '3129050': 'Шлейф скв №721 Астраханское ГКМ - УППГ-3А',
  '3129049': 'Шлейф скв №722 Астраханское ГКМ - УППГ-3А',
  '80000012742': 'Шлейф скв №723',
  '80000174320': 'Шлейф скв №724',
  '80000017957': 'Шлейф скв №726',
  '3129018': 'Шлейф скв №77 Астраханское ГКМ - УППГ-2',
  '3129079': 'Шлейф скв №828 Астраханское ГКМ - УППГ-6',
  '80000011327': 'Шлейф скв №829 Астраханское ГКМ - УППГ-6',
  '80000013774': 'Шлейф скв №834 Астраханское ГКМ - УППГ-6',
  '80000262269': 'Шлейф скв №841',
  '80000008832': 'Шлейф скв №907',
  '3129082': 'Шлейф скв №908 Астраханское ГКМ - УППГ-9',
  '3129085': 'Шлейф скв №914 Астраханское ГКМ - УППГ-9',
  '3129087': 'Шлейф скв №918 Астраханское ГКМ - УППГ-9',
  '3129089': 'Шлейф скв №922 Астраханское ГКМ - УППГ-9',
  '3129090': 'Шлейф скв №923 Астраханское ГКМ - УППГ-9',
  '3129091': 'Шлейф скв №924 Астраханское ГКМ - УППГ-9',
  '3128997': 'Шлейф скв №93 Астраханское ГКМ - УППГ-1',
  '3129094': 'Шлейф скв №938 Астраханское ГКМ - УППГ-9',
  '3129010': 'Шлейф скв №97 Астраханское ГКМ - УППГ-2',
  '80000418953': 'Шлейф скв. № 1109 Астраханское ГКМ УППГ-1',
  '80000418902': 'Шлейф скв. № 4450 Астраханское ГКМ УППГ-4',
  '80000418971': 'Шлейф скв. № 613 Астраханское ГКМ УППГ-6',
  '80000418998': 'Шлейф скв. № 916 Астраханское ГКМ УППГ-9',
  '80000418992': 'Шлейф скв. № 920 Астраханское ГКМ УППГ-9',
  '80000418986': 'Шлейф скв. № 939 Астраханское ГКМ УППГ-3А',
  '80000418980': 'Шлейф скв. № 9929 Астраханское ГКМ УППГ-9',
  '80000162779': 'Шлейф скв. №2062',
  '80000008577': 'Шлейф скв. №4429 Астраханское ГКМ - УППГ-4',
  '80000008574': 'Шлейф скв. №4436 Астраханское ГКМ - УППГ-4',
  '80000164738': 'Шлейф скв. №532',
  '80000247169': 'Шлейф скв. №603',
  '80000162761': 'Шлейф скв. №620',
  '80000162764': 'Шлейф скв. №641',
  '80000162776': 'Шлейф скв. №707',
  '80000162770': 'Шлейф скв. №844',
  '80000012972': 'Шлейф скв. №930',
  '80000162767': 'Шлейф скв. №931',
  '80000238776': 'Шлейф скв.№541 Астраханское ГКМ - УППГ-1',
  '80000182343': 'Шлейф скв.№619',
  '1158644': 'Э/п Миннибаево-Казань, р/н  р. Меша, 222,56 км',
  '1158642': 'Э/п Миннибаево-Казань, р/н  р. Шешма, 87 км',
  '1158645': 'Э/п Миннибаево-Казань, р/н  р.Казанка, 276,93 км',
  '1158643': 'Э/п Миннибаево-Казань, р/н р. Кама, 178,67 км',
  '1153994': 'Этанопровод Миннибаево-Казань',
  '1153996': 'Этанопровод Оренбург-Казань',
  '40002394341': 'Южно - Европейский газопровод (участок Починки - Анапа 978-1168)',
  '6615921': 'Южно - Европейский газопровод (участок Починки - Анапа)',
  '230000647066': 'Южно-Европейский газопровод (участок Писаревка-Анапа)',
  '1156756': 'Юрга-Новосибирск',
  '1153853': 'Якшуновская СПХГ-КС Белоусово',
  '1153896': 'Ям-Ижора -Гатчина',
  '180000000293': 'Ямбург - Елец 1  Ду 1400',
  '180000000300': 'Ямбург - Прогресс  Ду 1400',
  '180000000296': 'Ямбург- Елец 2   Ду 1400',
  '180000000303': 'Ямбург- Тула 1   Ду 1400',
  '1153665': 'Ямбург-Елец I',
  '1154095': 'Ямбург-Елец I (лупинг)',
  '1154096': 'Ямбург-Елец I (лупинг)',
  '1154126': 'Ямбург-Елец I (лупинг), 1655 км',
  '1158775': 'Ямбург-Елец I, р/н р. Сура, 2494,6 км',
  '1157768': 'Ямбург-Елец I, р/н., р. Ныда, 183,6 км',
  '1157809': 'Ямбург-Елец I, р/н., р.Обь, км 865, пр. Алешкинская, км 870',
  '1153669': 'Ямбург-Елец II',
  '1154076': 'Ямбург-Елец II (лупинг)',
  '1158647': 'Ямбург-Елец II р/н  р.Вятка, 2140,4 км',
  '1158323': 'Ямбург-Елец II, р.Чусовая, 1585,6 км',
  '1157796': 'Ямбург-Елец II, р/н., р. Казым, км 678,75',
  '1157823': 'Ямбург-Елец II, р/н., р. Лозьва, км 1226,2',
  '1157775': 'Ямбург-Елец II, р/н., р. Надым, км 329,65',
  '1157772': 'Ямбург-Елец II, р/н., р. Правая Хетта, км 316,25',
  '1157805': 'Ямбург-Елец II, р/н., р.Амня, км 713',
  '1157810': 'Ямбург-Елец II, р/н., р.Обь, км 870, пр. Алешкинская, км 875',
  '1158779': 'Ямбург-Зап. гр.  СССР (Прогресс), р/н р. Сура, 2500,6 км',
  '1157769': 'Ямбург-Зап. гр. СССР (Прогресс), р/н., р. Ныда, км 192',
  '1157811': 'Ямбург-Зап. гр. СССР (Прогресс), р/н., р.Обь, км 874, пр. Алешкинская, км 877',
  '1154100': 'Ямбург-Западная Граница (Прогресс) (лупинг)',
  '1154130': 'Ямбург-Западная Граница (лупинг), 1431 км',
  '1154132': 'Ямбург-Западная Граница (лупинг), 1960 км',
  '1153687': 'Ямбург-Западная граница СССР (Прогресс)',
  '1153690': 'Ямбург-Поволжье',
  '180000000310': 'Ямбург-Поволжье  Ду 1400',
  '1157767': 'Ямбург-Поволжье, р/н., р. Ныда, км 195,3',
  '1157806': 'Ямбург-Поволжье, р/н., р.Амня, км 716,5',
  '180000000306': 'Ямбург-Тула 2  Ду 1400',
  '1153688': 'Ямбург-Тула I',
  '1154101': 'Ямбург-Тула I (лупинг)',
  '99000009757880': 'Ямбург-Тула I (лупинг)',
  '1158312': 'Ямбург-Тула I, р.Кама, 1683,46 км',
  '1158782': 'Ямбург-Тула I, р/н р.Волга, 2297,65 км',
  '1158783': 'Ямбург-Тула I, р/н р.Сура, 2441,35 км',
  '1157776': 'Ямбург-Тула I, р/н., р. Надым, км 334,8',
  '1157812': 'Ямбург-Тула I, р/н., р.Обь, км 878, пр. Алешкинская, км 883',
  '1153689': 'Ямбург-Тула II',
  '1154102': 'Ямбург-Тула II (лупинг)',
  '1154133': 'Ямбург-Тула II (лупинг)',
  '8474661': 'Ямбург-Тула II (лупинг)',
  '99000009757881': 'Ямбург-Тула II (лупинг)',
  '1157813': 'Ямбург-Тула II, р/н., р.Обь, км 878, пр. Алешкинская, км 883',
  '2341670': 'Яр-Омутнинск',
  '1154034': 'Яхрома-Ногинск (КГМО-II)',
  '1256892': 'аул Адыге-Хабль',
  '1256346': 'аул Псыж',
  '1257178': 'г. Аксай Казахстана',
  '1159334': 'г. Борисоглебск, р/н, р. Хопер, 18 км ',
  '1158516': 'г. Верхний Уфалей, ГРС-1, р/н., оз. Иртяш, 23,95 км',
  '40000083258': 'г. Ипатово (лупинг)',
  '1158255': 'г. Покров, р/н., р. Клязьма, 13,6 км',
  '1251486': 'г.Азнакаево',
  '1259242': 'г.Алапаевск',
  '1257860': 'г.Ардатов',
  '1256082': 'г.Ардон',
  '1255492': 'г.Аркадак',
  '1252770': 'г.Асбест (ГРС-1)',
  '1252074': 'г.Асбест (ГРС-2)',
  '1255256': 'г.Астрахань, ГРС-2 - ГРС-3А , 1 н.',
  '1255258': 'г.Астрахань, ГРС-2 - ГРС-3А, 2 н.',
  '1255660': 'г.Астрахань, ГРС-3А',
  '1255836': 'г.Астрахань, ГРС-4 - ГРС-1А, 1 н.',
  '1255824': 'г.Астрахань, ГРС-4 - ГРС-1А, 2 н.(резервн.)',
  '1259042': 'г.Ачит',
  '1258956': 'г.Аша',
  '1252956': 'г.Балашов',
  '1256692': 'г.Барнаул, ГРС-3',
  '1254504': 'г.Белёв',
  '1256084': 'г.Беслан',
  '1252018': 'г.Благодарный',
  '1252058': 'г.Бобров',
  '1251838': 'г.Богданович',
  '1257312': 'г.Богучар',
  '1252730': 'г.Бор (ГРС Зарубино)',
  '1257336': 'г.Борисоглебск',
  '1254374': 'г.Брянск, ГРС-1',
  '1253198': 'г.Буденновск',
  '1256172': 'г.Буденновск, з-д Пластмасс',
  '1256622': 'г.Буденновск-2',
  '1258478': 'г.Бузулук',
  '1251460': 'г.Буинск',
  '1257362': 'г.Буйнакск',
  '1251960': 'г.Булгары',
  '1257262': 'г.Бутурлиновка',
  '1257098': 'г.Быково',
  '1254524': 'г.Верхний Тагил ГРЭС',
  '1254690': 'г.Верхний Уфалей,ГРС-1',
  '1254738': 'г.Верхняя Пышма (ГРС-1А)',
  '1255750': 'г.Верхняя Тура',
  '1251860': 'г.Владимир-1',
  '1255036': 'г.Владимир-3',
  '1258868': 'г.Волгоград, ГРС-1',
  '1256452': 'г.Волгоград, ГРС-3',
  '1256408': 'г.Волгоград, ГРС-7',
  '230000022116': 'г.Волгоград, ГРС-7 новая',
  '1256852': 'г.Волгоград, п.Городище, ГРС-2, 2н.',
  '1258774': 'г.Волжский (ГРС-1)',
  '1257088': 'г.Волжский (ГРС-2)',
  '1257196': 'г.Волчанск',
  '70000067722': 'г.Вольск',
  '1252546': 'г.Вольск, ГРС-1, 1 н.',
  '1258518': 'г.Вольск, ГРС-1, 2 н.',
  '1254770': 'г.Воронеж, ГРС-1',
  '1254362': 'г.Воронеж, ГРС-2',
  '1158273': 'г.Воронеж, ГРС-2, р/н., р.Дон, 2,7 км',
  '1254684': 'г.Воронеж, ГРС-3',
  '1254000': 'г.Воротынск',
  '1253448': 'г.Воскресенск, ГРС Минудобрения',
  '30000675650': 'г.Выкса-2',
  '1253354': 'г.Вятские Поляны',
  '1252914': 'г.Гай(ГРС-2)',
  '1255812': 'г.Глазов',
  '1251448': 'г.Глазуновка',
  '1254580': 'г.Городовиковск-2',
  '1253876': 'г.Горький-3',
  '1251888': 'г.Губкин, I н.',
  '1255190': 'г.Далматово',
  '90001063989': 'г.Дмитриев',
  '1252998': 'г.Екатеринбург, ГРС-2',
  '1251414': 'г.Екатеринбург, ГРС-3',
  '1251738': 'г.Екатеринбург, ГРС-4',
  '1252826': 'г.Елабуга-1',
  '1256280': 'г.Ессентуки, вин.сады',
  '1254250': 'г.Железногорск (1-я нитка)',
  '1254248': 'г.Железногорск (2-я нитка)',
  '1256382': 'г.Жирновск',
  '1257976': 'г.Заводоуковск',
  '1256252': 'г.Зеленокумск',
  '1255736': 'г.Ижевск, ГРС-3',
  '110000002181': 'г.Ижевск,ГРС-3/2-я очередь/',
  '1257972': 'г.Ишим',
  '1252572': 'г.Йошкар-Ола',
  '30000507770': 'г.Йошкар-Ола-2',
  '1254454': 'г.Казань-5, ТЭЦ-3',
  '1256394': 'г.Калач на Дону',
  '1255494': 'г.Калининск',
  '1251438': 'г.Калуга, ГРС-2',
  '1254946': 'г.Каменка',
  '1252000': 'г.Каменск-Уральский',
  '1256092': 'г.Карабулак',
  '1256884': 'г.Карачаевск',
  '1252336': 'г.Касли, ГРС-2',
  '1256986': 'г.Каспийский Лагань',
  '1252850': 'г.Катав-Ивановск',
  '1255106': 'г.Катайск',
  '1255830': 'г.Качканар',
  '1251552': 'г.Кашира',
  '1255402': 'г.Кемерово (ГРС-1), 1 нитка',
  '1255020': 'г.Кемерово (ГРС-1), 2 нитка',
  '1255042': 'г.Кемерово (ГРС-2)',
  '140000016285': 'г.Кизилюрт',
  '1257856': 'г.Кизляр',
  '1252198': 'г.Киров, ГРС-2',
  '1256300': 'г.Кисловодск, 1 н.',
  '1256232': 'г.Кисловодск, 2 н.',
  '1251930': 'г.Козельск',
  '1159407': 'г.Кострома-4, р/н р. Волга, 48,2 км',
  '1251528': 'г.Красный Кут',
  '1254352': 'г.Красный Сулин-2',
  '1581971': 'г.Кудымкар',
  '1253310': 'г.Курган',
  '1253292': 'г.Курск, ГРС-1А',
  '1254468': 'г.Курск, ГРС-2',
  '1259046': 'г.Кыштым',
  '1256462': 'г.Ленинск',
  '1256022': 'г.Ливны',
  '1252196': 'г.Лиски',
  '1252830': 'г.Магнитогорск,ГРС-4',
  '1252838': 'г.Магнитогорск.ГРС-3, 1н.',
  '1252840': 'г.Магнитогорск.ГРС-3, 2н.',
  '1252160': 'г.Мамадыш',
  '1258472': 'г.Медногорск',
  '90002651849': 'г.Медынь',
  '1251456': 'г.Мензелинск',
  '1254100': 'г.Миасс',
  '1258128': 'г.Миллерово',
  '1252316': 'г.Михайлов',
  '1257244': 'г.Михайловка',
  '1252096': 'г.Мичуринск',
  '1255670': 'г.Надым, 1 н.',
  '1255622': 'г.Надым, 2 н.',
  '1257446': 'г.Нальчик, ГРС-1',
  '1254180': 'г.Нарофоминск 2н.',
  '1256230': 'г.Нарткала, 2 нитка',
  '1259300': 'г.Невинномысск, ГРС-1, 2 н.',
  '1251550': 'г.Невьянск',
  '1255654': 'г.Нижневартовск, ГРС-1, 1 н.',
  '1255656': 'г.Нижневартовск, ГРС-1, 2 н.',
  '1254050': 'г.Нижнекамск, ГРС-2',
  '1252206': 'г.Нижнекамск, ГРС-3',
  '1254194': 'г.Нижний Ломов',
  '1251914': 'г.Нижний Тагил, ГРС-2',
  '1257106': 'г.Николаевск',
  '1257232': 'г.Новоаннинск',
  '1251526': 'г.Новозыбков',
  '1252482': 'г.Новокузнецк (ГРС-2)',
  '1158489': 'г.Новокузнецк (ГРС-2), р/н., р. Томь, 4,15 км',
  '1252130': 'г.Новоменделеевск, хим.з-д',
  '1254018': 'г.Новомосковск, ПО "Азот", ГРС-3',
  '1255394': 'г.Новосибирск (ГРС-2)',
  '1158742': 'г.Новосибирск (ГРС-4), р/н через р.Обь, 41,85 км',
  '1255392': 'г.Новосибирск (ГРС-5)',
  '2250314': 'г.Новосибирск (ГРС-7), электродный з-д',
  '1251472': 'г.Новоузенск',
  '1257328': 'г.Новохоперск',
  '1252996': 'г.Нурлат',
  '1255388': 'г.Омск (ГРС-1)',
  '1255384': 'г.Омск (ГРС-4)',
  '1258368': 'г.Омск, ГРС-5',
  '1257256': 'г.Павловск',
  '1159348': 'г.Павловск, р/н, р.Осередь, 2км',
  '1251974': 'г.Первоуральск, ГРС-1',
  '1259072': 'г.Первоуральск, ГРС-2',
  '1255542': 'г.Пермь-76 (Бершеть)',
  '1257272': 'г.Поворино',
  '1253054': 'г.Покров',
  '1254432': 'г.Полевской',
  '1258346': 'г.Пролетарск',
  '1253470': 'г.Рассказово, ГРС-1',
  '1252926': 'г.Ревда',
  '1252002': 'г.Реж',
  '1252168': 'г.Россошь',
  '1257310': 'г.Россошь',
  '1254608': 'г.Рошаль',
  '1255336': 'г.Ряжск',
  '1581284': 'г.Салехард',
  '1259192': 'г.Саратов, ГРС-2А',
  '1254392': 'г.Сасово',
  '1257206': 'г.Североуральск',
  '1254978': 'г.Сердобск',
  '1257200': 'г.Серов',
  '1254142': 'г.Скопин',
  '1254782': 'г.Среднеуральск, СУГРЭС',
  '1252014': 'г.Ставрополь, ГРС-3',
  '1253608': 'г.Стародуб, ГРС (концевая)',
  '1253494': 'г.Сургут, ГРЭС-1, 1 н.',
  '1253496': 'г.Сургут, ГРЭС-1, 2 н.',
  '1253270': 'г.Сургут, ГРЭС-2',
  '1258154': 'г.Суровикино',
  '1252220': 'г.Сухой Лог, ГРС (концевая)',
  '1252836': 'г.Талдом',
  '1251562': 'г.Тетюши',
  '1257938': 'г.Тобольск',
  '1255642': 'г.Томск, ГРС-1',
  '1255644': 'г.Томск, ГРС-3',
  '1255044': 'г.Томск, Томский отвод, 1нитка',
  '1158488': 'г.Томск, Томский отвод, 2 н., р/н., р.Томь, протока Моряковская и Тигильдеевская,  45,8 км',
  '1253960': 'г.Томск, Томский отвод, 2 нитка',
  '1255360': 'г.Томск, химкомбинат',
  '1255640': 'г.Топки',
  '1253550': 'г.Троицк,уч.хоз."Новотроицкий"',
  '1256210': 'г.Тырныауз',
  '1257950': 'г.Тюмень, ТЭЦ-1',
  '1257926': 'г.Тюмень, ТЭЦ-2',
  '1253378': 'г.Узловая, Новомосковская ГРС-1',
  '1259232': 'г.Урень',
  '1256732': 'г.Урюпинск',
  '1256318': 'г.Усть Джегута',
  '1251422': 'г.Усть-Катав',
  '1252062': 'г.Уфалей-2, 1н.',
  '1251510': 'г.Фокино',
  '1256690': 'г.Фролово',
  '1257764': 'г.Ханты-Мансийск',
  '1256486': 'г.Хасавюрт',
  '1255564': 'г.Чайковский-1',
  '1158309': 'г.Чайковский-1, р. Кама, 19,5 км',
  '1254682': 'г.Чебаркуль',
  '1255310': 'г.Челябинск, ГРС-1',
  '1255342': 'г.Челябинск, ГРС-2',
  '1255436': 'г.Челябинск, ГРС-3',
  '1253236': 'г.Челябинск, ГРС-4',
  '1259082': 'г.Челябинск-70',
  '1256064': 'г.Черкесск',
  '1254862': 'г.Чистополь',
  '1258600': 'г.Чистополь-2',
  '1253532': 'г.Чкаловск',
  '1255888': 'г.Шадринск',
  '1254434': 'г.Шатура',
  '1581611': 'г.Шумиха',
  '1581668': 'г.Щучье',
  '1253850': 'г.Энгельс, ГРС-2',
  '90000357673': 'г.Эртиль',
  '1255728': 'г.Яйва',
  '1258024': 'г.Ялуторовск',
  '1253396': 'г.г. Верхняя Салда, Нижняя Салда',
  '3167008': 'г.о.г. ДКС-1 - ДКС-2',
  '2552696': 'г.о.г. УКПГ-12-УКПГ-15',
  '1581170': 'г.о.г. УКПГ-15-УКПГ-14',
  '990007712666': 'газопровод-отвод ГРС Сокуры',
  '300000600333': 'газопровод-отвод Кобрин-Брест 2 нитка',
  '300000574000': 'газопровод-отвод Минск-Гомель',
  '7145234': 'газопровод-отвод к АГРС Кара-Балта',
  '300000598353': 'газопровод-отвод к ГРС Белоозерск 2 нитка',
  '300000937057': 'газопровод-отвод к ГРС Брест-1',
  '300000601146': 'газопровод-отвод к ГРС Витебск-1',
  '300000603655': 'газопровод-отвод к ГРС Витебск-2',
  '300000591043': 'газопровод-отвод к ГРС Восточная 1 нитка',
  '990007676470': 'газопровод-отвод к ГРС Восточная 2 нитка',
  '300000624718': 'газопровод-отвод к ГРС Гродно-1',
  '300000555633': 'газопровод-отвод к ГРС Гродно-2',
  '990007445955': 'газопровод-отвод к ГРС Западная 1 нитка',
  '300000590890': 'газопровод-отвод к ГРС Западная 2 нитка',
  '300000582871': 'газопровод-отвод к ГРС Клецк',
  '30004247438': 'газопровод-отвод к ГРС Кокшамары',
  '300000585293': 'газопровод-отвод к ГРС Кореличи',
  '300000611084': 'газопровод-отвод к ГРС Краснополье',
  '300000603380': 'газопровод-отвод к ГРС Лиозно',
  '300000586608': 'газопровод-отвод к ГРС Логойск',
  '300000583265': 'газопровод-отвод к ГРС Микашевичи',
  '300000602328': 'газопровод-отвод к ГРС Могилев-1',
  '300000608490': 'газопровод-отвод к ГРС Могилев-3',
  '300000600894': 'газопровод-отвод к ГРС Новогрудок',
  '300000582754': 'газопровод-отвод к ГРС Новолукомль 2 нитка',
  '300000582764': 'газопровод-отвод к ГРС Новополоцк',
  '990007442830': 'газопровод-отвод к ГРС Поставы',
  '300000606464': 'газопровод-отвод к ГРС Рюмино',
  '300000580588': 'газопровод-отвод к ГРС Светлогорск',
  '990007676413': 'газопровод-отвод к ГРС Северная',
  '300000603063': 'газопровод-отвод к ГРС Сенно',
  '300000583621': 'газопровод-отвод к ГРС Солигорск',
  '300000583150': 'газопровод-отвод к ГРС Хойники',
  '300000609112': 'газопровод-отвод к ГРС Хотимск',
  '300000611063': 'газопровод-отвод к ГРС Чериков',
  '300000582811': 'газопровод-отвод к ГРС Шумилино',
  '300000584661': 'газопровод-отвод к ГРС Щучин',
  '990007676440': 'газопровод-отвод к Осиповичскому ПХГ',
  '300000570775': 'газопровод-отвод к Прибугскому ПХГ',
  '300000603243': 'газопровод-отвод к г.Витебск II нитка',
  '300000584716': 'газопровод-отвод к г.Петриков, Житковичи',
  '300000585187': 'газопровод-перемычка между МГ Торжок-Долина (км 3222,32) и газопроводом-отводом к ГРС-3А г.Гомеля (км 0,03)',
  '300001100711': 'газопровод-перемычка между газопроводом-отводом к ГРС Могилев-1 (км 90,34) и газопроводом-отводом к ГРС Могилев-3 (км 57,67)',
  '30002400497': 'гг. Оханск, Киров (реконструкция)',
  '1254446': 'гг.Алгасово, Тамбов',
  '1253274': 'гг.Каменск-Уральский, Двуреченск',
  '1259104': 'гг.Карталы.Рудный.Кустанай',
  '1258994': 'гг.Красноуфимск, Арти,Ачит',
  '1253910': 'гг.Кулебаки, Выкса',
  '1252724': 'гг.Навашино, Муром',
  '1252564': 'гг.Оргтруд, Гусь-Хрустальный',
  '1253178': 'гг.Оханск, Киров (Кир.обл)',
  '1253010': 'гг.Первоуральск, Ревда, 1 н.',
  '1253008': 'гг.Первоуральск, Ревда, 2 н.',
  '1158852': 'гг.Салехард, Лабытнанги, п.Харп',
  '2248581': 'гг.Салехард, Лабытнанги, п.Харп, р/н, р.Обь, 316 км',
  '1253232': 'гг.Сухой Лог, Богданович,Асбест.Реж',
  '1254766': 'гг.Чебаркуль, Катав-Ивановск, 1 н.',
  '100001600953': 'гг.Чебаркуль, Катав-Ивановск, 2 н.',
  '1258958': 'гг.Чебаркуль, Катав-Ивановск, 3 н.',
  '1259006': 'гг.Чебаркуль-Миасс-Златоуст-Сатка',
  '110001070437': 'гг.Чусовой, Березники, Соликамск 1 н.(нов)',
  '1259012': 'гг.Чусовой, Березники, Соликамск 1н.',
  '1253942': 'гг.Чусовой, Березники, Соликамск 2 н.',
  '110000859512': 'гг.Чусовой, Березники, Соликамск 2 н.(нов)',
  '1254644': 'д.Велижаны',
  '1255748': 'д.Кленовая',
  '1158798': 'к г.Волгоград 1 очередь',
  '1581419': 'к г.Морозовск',
  '1581221': 'к г.г. Архангельск, Северодвинск',
  '230000001252': 'к ст.Милютинская',
  '160000374717': 'к энергоблоку № 2 Калининградской ТЭЦ-2',
  '1252612': 'к-з им.Чапаева, п. Дергачи',
  '160000018500': 'лупинг 1 к ГРС Шоссейная',
  '160000018502': 'лупинг 2 к ГРС Шоссейная',
  '1154084': 'лупинг от перем. Оренбург-Заинск-Совхозное',
  '1159179': 'н.п. Камские Поляны, р/н, р. Шешма, 19,33 км',
  '1258786': 'н.п. Ст.Дрюш',
  '1251466': 'н.п.Апастово',
  '190000373877': 'н.п.Елизаветино',
  '1258822': 'н.п.Камские Поляны',
  '100000130667': 'н.п.Мишкино',
  '1581974': 'н.п.Н.Тура',
  '210000097391': 'обводной г/о на ГРС Эжва',
  '210001374105': 'обводной к ГРС Сыктывкар',
  '1256398': 'п. М.Горького',
  '1258512': 'п.Адык',
  '30000156509': 'п.Барамзы',
  '1255332': 'п.Баранча',
  '1255062': 'п.Береговой',
  '1254648': 'п.Бравый',
  '1253066': 'п.Верх-Нейвинск, 1н.',
  '1259066': 'п.Верх-Нейвинск, 2н.',
  '1259244': 'п.Веселовский',
  '1258748': 'п.Демьяс',
  '1259254': 'п.Джетыгора',
  '1256672': 'п.Донгуз',
  '1256238': 'п.Иноземцево',
  '1257966': 'п.Исетский',
  '1252372': 'п.Камский, леспромхоз',
  '1255568': 'п.Карабаш',
  '1257980': 'п.Каскара, Тюменская п/ф-ка',
  '3209272': 'п.Кигач',
  '1256390': 'п.Комсомольский',
  '1256330': 'п.Красный Курган (Конезавод №168)',
  '1251432': 'п.Лакинск',
  '1251378': 'п.Ленинский',
  '1256720': 'п.Лобва',
  '1257946': 'п.Маслянка',
  '2203678': 'п.Мучкап',
  '1253528': 'п.Непецино',
  '1257188': 'п.Новосакмарск',
  '230000022433': 'п.Октябрьский - с.Садовое',
  '1257978': 'п.Онохино, Пышминская п/ф-ка',
  '1258174': 'п.Орловский',
  '1252410': 'п.Перелюб',
  '1253282': 'п.Рычково, ГРС Истра',
  '1255512': 'п.Селты',
  '1256218': 'п.Советское (г.Къашкатау)',
  '1253162': 'п.Томаровка',
  '1251500': 'п.Тукай-Кырлай',
  '1257922': 'п.Упорово',
  '1252652': 'п.Фершампенуаз (ГРС Ю.Рудник)',
  '1259204': 'п.Чаадаевка',
  '1258682': 'п.Яшкино',
  '1159420': 'пгт. Романовка, р/н р. Хопер, 26 км',
  '1251606': 'пгт.Аксубаево',
  '1251484': 'пгт.Анна',
  '1253268': 'пгт.Б.Карабулак',
  '1252348': 'пгт.Багаевский',
  '1254874': 'пгт.Беково',
  '1252962': 'пгт.Билимбай',
  '1259052': 'пгт.Варгаши',
  '1257692': 'пгт.Верховье',
  '1259332': 'пгт.Грибановский',
  '1159335': 'пгт.Грибановский, р/н, р.Ворона (6 км), р.старица р.Ворона (3,8 км)',
  '1256366': 'пгт.Даниловка',
  '1251702': 'пгт.Двуреченск',
  '1257170': 'пгт.Екатериновка',
  '1257288': 'пгт.Елань',
  '1257776': 'пгт.Игрим 2н.',
  '1256352': 'пгт.Иловля',
  '1251464': 'пгт.Камское Устье',
  '1253160': 'пгт.Каргаполье',
  '1251886': 'пгт.Кубинка',
  '1253142': 'пгт.Кукмор-1н',
  '1259262': 'пгт.Кукмор-2н',
  '1257242': 'пгт.Кумылженский',
  '1255096': 'пгт.Лев Толстой',
  '1251476': 'пгт.Муслюмово',
  '3150587': 'пгт.Муслюмово(лупинг)',
  '1253488': 'пгт.Навля',
  '1256982': 'пгт.Оранжереи',
  '1256374': 'пгт.Петров Вал',
  '1252928': 'пгт.Романовка',
  '1252844': 'пгт.Самойловка',
  '1251566': 'пгт.Сосенский',
  '1257086': 'пгт.Ср.Ахтуба',
  '1259044': 'пгт.Тайгинка',
  '1257258': 'пгт.Таловая',
  '1254638': 'пгт.Тамала',
  '1257144': 'пгт.Тучково',
  '1255688': 'пгт.Тюльган',
  '1254388': 'пгт.Шилово',
  '1581887': 'перемычка к г-ду Казань-Н.Новгород',
  '300000707056': 'перемычка между МГ Ивацевичи-Долина I и газопроводом-отводом к ГРС Гродно-2 (кран 109)',
  '160000516294': 'подводящий газопровод к площадке ПХГ',
  '20000054693': 'р.Сосыка - ст. Староминская',
  '1257070': 'р.п.Ст.Полтавка (Верхний Еруслан)',
  '2157920': 'р.п.Терновка',
  '1258236': 'р.п.Чернышковский',
  '1251506': 'р.ц. Шарлык',
  '1252340': 'р.ц.Абдулино',
  '1257236': 'р.ц.Алексеевский',
  '1251560': 'р.ц.Базарные Матаки',
  '300000652640': 'р/н подводного перехода МГ Торжок-Минск-Ивацевичи I через р.Березина',
  '300000692408': 'р/н подводного перехода газопровода-отвода к ГРС Гродно-2 через Зельвенское водохранилище',
  '300000706782': 'р/н подводного перехода газопровода-отвода к ГРС Светлогорск через р.Березина',
  '300000684082': 'р/н подводного перехода газопровода-отвода к ГРС Хотимск через р.Сож',
  '300000586576': 'р/н подводного перехода газопровода-перемычки между газопроводом-отводом Минск-Гомель (км 293,3) и газопроводом-отводом Щорс-Гомель через р.Сож',
  '110000235601': 'резервное подключение межсистемной перемычки "Ямбург-Зап.граница" - "Ямбург-Тула I"',
  '1257072': 'с-з "40 лет Октября" (с.Кайсацкое)',
  '1259076': 'с-з "Баженовский"',
  '1257108': 'с-з "Вербинский" (с.Барановка)',
  '1256414': 'с-з "Котлубань", ГРС-6',
  '1257322': 'с-з "Краснопольский"',
  '1254236': 'с-з Заветы Ильича, ГРС Порослицы',
  '1257316': 'с-з Черноземный',
  '1258146': 'с-з им.Фрунзе (х. Большой)',
  '1257076': 'с-з им.Чапаева (с.Савина)',
  '1258610': 'с. М. Савалеевка',
  '1252218': 'с.Айдарово',
  '1251632': 'с.Актаныш',
  '1257410': 'с.Александровское',
  '1257440': 'с.Алтуд',
  '1158715': 'с.Аппастово, р/н,  р.Свияга, 62,22 км',
  '1256226': 'с.Аргудан',
  '1251902': 'с.Арзгир',
  '1258832': 'с.Ахматовка',
  '1251646': 'с.Б.Атня',
  '1251698': 'с.Б.Кайбицы',
  '1581569': 'с.Б.Копёны',
  '1255276': 'с.Бабаюрт',
  '1158641': 'с.Базарные Матаки, р/н, р.Черемшан, 14 км',
  '1254824': 'с.Бакуры',
  '1251850': 'с.Балтаси',
  '1581926': 'с.Батырево (Комсомольское)',
  '1256602': 'с.Билярск',
  '1251518': 'с.Бондари',
  '140000022163': 'с.Ботлих',
  '1256980': 'с.Бударино',
  '1257268': 'с.В.Мамон',
  '1251942': 'с.Варна',
  '1257924': 'с.Викулово',
  '1254576': 'с.Виноградное',
  '1254572': 'с.Винодельное',
  '1256730': 'с.Вишневка',
  '1257320': 'с.Воробьевка',
  '1256132': 'с.Гизель',
  '1253322': 'с.Головчино',
  '1255606': 'с.Грачевка',
  '1258494': 'с.Грачевка',
  '1257120': 'с.Дейское',
  '1257118': 'с.Дзуарикау',
  '1252618': 'с.Дивное',
  '1256670': 'с.Дружба',
  '1252726': 'с.Духовницкое',
  '1581383': 'с.Екатериновка',
  '1256220': 'с.Жемтала',
  '1256204': 'с.Зеленая Роща',
  '1255354': 'с.Идолга',
  '1256766': 'с.Иргаклы',
  '1256100': 'с.Казмьинское',
  '1256458': 'с.Каменномостское',
  '1257438': 'с.Карагач',
  '1251636': 'с.Караса',
  '1256362': 'с.Киреево, с-з Краснозвездинский',
  '1252070': 'с.Котово',
  '1256968': 'с.Красный Яр',
  '1255604': 'с.Кугульта',
  '1251708': 'с.Кундюковка',
  '1252022': 'с.Кутлу-Букаш',
  '1252024': 'с.Левашево',
  '1257340': 'с.Леваши',
  '1256830': 'с.Липовка',
  '1581977': 'с.Лукино',
  '230000080239': 'с.Малые Дербеты',
  '1256396': 'с.Н.Рогачик, ГРС-10',
  '1581317': 'с.Народное',
  '1252720': 'с.Нижнедевицк',
  '1251958': 'с.Николаевка',
  '1256062': 'с.Новая Деревня',
  '1257974': 'с.Новая Заимка',
  '1256896': 'с.Новое Хамидие',
  '1253394': 'с.Новошешминск',
  '1256624': 'с.Ногир',
  '1256816': 'с.Озерное',
  '1251804': 'с.Пелагиада',
  '1254546': 'с.Первомайское',
  '1251730': 'с.Петровское',
  '1251848': 'с.Покровское',
  '1251524': 'с.Преображенка',
  '1257090': 'с.Рахинка',
  '1257716': 'с.Русский Брод',
  '1257462': 'с.Сармаково',
  '1252028': 'с.Сарманово',
  '1257858': 'с.Сладково',
  '1252624': 'с.Соленое',
  '1252036': 'с.Софиевское',
  '1251964': 'с.Ст.Дрожанное',
  '1257500': 'с.Степное',
  '1256706': 'с.Тальменка',
  '1257292': 'с.Тарасовка',
  '1253744': 'с.Тарутино',
  '1256752': 'с.Терек',
  '1256164': 'с.Турксад',
  '1251966': 'с.Тюлячи',
  '1255364': 'с.Усолье',
  '1256328': 'с.Учкекен',
  '140000065782': 'с.Хунзах',
  '1252128': 'с.Ципья',
  '1254060': 'с.Черемшан',
  '1256148': 'с.Чикола',
  '1251650': 'с.Шемурша',
  '1252020': 'с.Щитцы',
  '1251962': 'с.Юхмачи',
  '1252166': 'с.Якеево',
  '1252334': 'с.Ямное',
  '1254636': 'с.Яшалта',
  '1256576': 'ст. Алексеевская',
  '20000054756': 'ст. Ленинградская - г. Ейск',
  '1253100': 'ст.Задоно-Кагальницкая, п/ф-ка',
  '1256872': 'ст.Зольская, 2 нитка',
  '1257466': 'ст.Зольская, I нитка',
  '1257454': 'ст.Курская',
  '1257294': 'ст.Мальчевская',
  '1256090': 'ст.Нестеровская',
  '1256850': 'ст.Островская',
  '1256306': 'ст.Сторожевая',
  '1256308': 'т/к "Южный"',
  '40001307239': 'т\\п между Астраханский ГПЗ-Замьяны (83 км.) и Макат - Северный Кавказ (496 км.)',
  '1258204': 'х.Кривов',
  '1258340': 'х.Манойлин',
  '1256416': 'х.Паншино',
}

PIPELINE_BY_NAMES = {name: iid for iid, name in PIPELINE_BY_IDS.items()}
